<?php
/**
 * Ajax Actions
 *
 * @package   rcp
 * @copyright Copyright (c) 2018, Restrict Content Pro team
 * @license   GPL2+
 * @since     1.1.1
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Refresh forms via ajax
 *
 * @since 1.1.1
 * @return void
 */
function rcp_convertkit_refresh_forms() {

	check_ajax_referer( 'rcp_convertkit_nonce', 'nonce' );

	$settings   = get_option( 'rcp_convertkit_settings' );
	$saved_list = isset( $settings['saved_list'] ) ? $settings['saved_list'] : false;
	$lists      = rcp_convertkit()->api_helper->get_lists( false );

	if ( empty( $lists ) ) {
		wp_send_json_error();
	}

	$list_html = '<option value="0" ' . selected( empty( $saved_list ), true, false ) . '>' . __( 'None', 'rcp-convertkit' ) . '</option>';

	foreach ( $lists as $list_id => $list_name ) {
		$list_html .= '<option value="' . esc_attr( $list_id ) . '" ' . selected( $saved_list, $list_id, false ) . '>' . esc_html( $list_name ) . '</option>';
	}

	wp_send_json_success( $list_html );
	exit;

}

add_action( 'wp_ajax_rcp_convertkit_refresh_forms', 'rcp_convertkit_refresh_forms' );