<?php

namespace RCP_Custom_Renew\Admin;

use RCP_Custom_Renew\Init as RCP_Custom_Renew;

class Levels {

	/**
	 * @var
	 */
	protected static $_instance;

	/**
	 * Only make one instance of \RCP_Custom_Renew\Levels
	 *
	 * @return Levels
	 */
	public static function get_instance() {
		if ( ! self::$_instance instanceof Levels ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	/**
	 * Add Hooks and Actions
	 */
	protected function __construct() {
		$this->hooks();
	}

	/**
	 * Actions and Filters
	 */
	protected function hooks() {

		// Add form field to subscription level add and edit forms
		add_action( 'rcp_add_subscription_form',  array( $this, 'meta_fields' ) );
		add_action( 'rcp_edit_subscription_form', array( $this, 'meta_fields' ) );

		// Actions for saving subscription seat count
		add_action( 'rcp_edit_subscription_level', array( $this, 'handle_meta_save' ), 10, 2 );
		add_action( 'rcp_add_subscription',        array( $this, 'handle_meta_save' ), 10, 2 );

	}

	/**
	 * Add meta fields to the RCP levels
	 * @param null $level
	 */
	public function meta_fields( $level = null ) {
		$renewal  = ( empty( $level->id ) ) ? 0 : RCP_Custom_Renew::meta_get( $level->id ); ?>

		<tr class="form-field">
			<th scope="row" valign="top">
				<label for="rcp-custom-renew"><?php _e( 'Renew', 'rcp-custom-renew' ); ?></label>
			</th>
			<td>
				<select id="rcp-custom-renew" type="text" name="rcp-custom-renew" >
					<option value="" ><?php _e( 'Default', 'rcp-custom-renew' ); ?></option>
					<option value="1" <?php selected( $renewal, '1' ); ?>><?php _e( 'Auto Renew', 'rcp-custom-renew' ); ?></option>
					<option value="2" <?php selected( $renewal, '2' ); ?>><?php _e( 'Do Not Auto Renew', 'rcp-custom-renew' ); ?></option>
				</select>
				<p class="description"><?php _e( 'Choose whether or not to auto renew this level.', 'rcp-custom-renew' ); ?></p>
			</td>
		</tr>

		<?php do_action( 'rcp_custom_renew_level_settings', $level ); ?>

	<?php
	}

	/**
	 * Save the member type for this subscription
	 *
	 * @param $subscription_id
	 * @param $args
	 */
	public function handle_meta_save( $subscription_id, $args ) {
		// make sure the member type is set
		$value = ( empty( $_POST['rcp-custom-renew'] ) ) ? 0 : absint( $_POST['rcp-custom-renew' ] );

		RCP_Custom_Renew::meta_save( $subscription_id, $value );
	}

}