<?php
/**
 * Plugin Name: Restrict Content Pro - Custom Renew
 * Plugin URL: https://skillfulplugins.com/plugins/rcp-custom-renew
 * Description: Allows you to handle level renewals on an individual basis
 * Version: 1.0.5
 * Author: iThemes
 * Author URI: https://ithemes.com/
 * Text Domain: rcp-custom-renew
 * Domain Path: languages
 * iThemes Package: rcp-custom-renew
 */

if ( !defined( 'RCP_CUSTOM_RENEW_PLUGIN_DIR' ) ) {
	define( 'RCP_CUSTOM_RENEW_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
}
if ( !defined( 'RCP_CUSTOM_RENEW_PLUGIN_URL' ) ) {
	define( 'RCP_CUSTOM_RENEW_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
}
if ( !defined( 'RCP_CUSTOM_RENEW_PLUGIN_FILE' ) ) {
	define( 'RCP_CUSTOM_RENEW_PLUGIN_FILE', __FILE__ );
}
if ( !defined( 'RCP_CUSTOM_RENEW_PLUGIN_VERSION' ) ) {
	define( 'RCP_CUSTOM_RENEW_PLUGIN_VERSION', '1.0.5' );
}
if ( ! defined( 'CAL_GREGORIAN' ) ) {
	define( 'CAL_GREGORIAN', 1 );
}

// EDD Licensing constants
define( 'RCP_CUSTOM_RENEW_STORE_URL', 'https://skillfulplugins.com' );
define( 'RCP_CUSTOM_RENEW_ITEM_NAME', 'Restrict Content Pro - Custom Renew' );

require_once( RCP_CUSTOM_RENEW_PLUGIN_DIR . 'vendor/autoload.php' );

/**
 * @var RCP_Custom_Renew\Init
 */
global $rcp_custom_renew;

if( version_compare( PHP_VERSION, '5.3', '<' ) ) {

} else {
	$rcp_custom_renew = rcp_custom_renew();
}

/**
 * Load plugin text domain for translations.
 *
 * @return void
 */
function rcp_custom_renew_load_textdomain() {

	// Set filter for plugin's languages directory
	$rcp_lang_dir = dirname( plugin_basename( RCP_CUSTOM_RENEW_PLUGIN_FILE ) ) . '/languages/';
	$rcp_lang_dir = apply_filters( 'rcp_custom_renew_languages_directory', $rcp_lang_dir );


	// Traditional WordPress plugin locale filter

	$get_locale = get_locale();

	if ( function_exists( 'rcp_compare_wp_version' ) && rcp_compare_wp_version( 4.7 ) ) {
		$get_locale = get_user_locale();
	}

	/**
	 * Defines the plugin language locale used in RCP.
	 *
	 * @var string $get_locale The locale to use. Uses get_user_locale()` in WordPress 4.7 or greater,
	 *                  otherwise uses `get_locale()`.
	 */
	$locale        = apply_filters( 'plugin_locale',  $get_locale, 'rcp-custom-renew' );
	$mofile        = sprintf( '%1$s-%2$s.mo', 'rcp-custom-renew', $locale );

	// Setup paths to current locale file
	$mofile_local  = $rcp_lang_dir . $mofile;
	$mofile_global = WP_LANG_DIR . '/rcp-custom-renew/' . $mofile;

	if ( file_exists( $mofile_global ) ) {
		// Look in global /wp-content/languages/rcp folder
		load_textdomain( 'rcp-custom-renew', $mofile_global );
	} elseif ( file_exists( $mofile_local ) ) {
		// Look in local /wp-content/plugins/easy-digital-downloads/languages/ folder
		load_textdomain( 'rcp-custom-renew', $mofile_local );
	} else {
		// Load the default language files
		load_plugin_textdomain( 'rcp-custom-renew', false, $rcp_lang_dir );
	}

}
add_action( 'init', 'rcp_custom_renew_load_textdomain' );

/**
 * @return \RCP_Custom_Renew\Init
 */
function rcp_custom_renew() {
	return RCP_Custom_Renew\Init::get_instance();
}



if ( ! function_exists( 'ithemes_rcp_custom_renew_updater_register' ) ) {
	function ithemes_rcp_custom_renew_updater_register( $updater ) {
		$updater->register( 'rcp-custom-renew', __FILE__ );
	}
	add_action( 'ithemes_updater_register', 'ithemes_rcp_custom_renew_updater_register' );

	require( __DIR__ . '/lib/updater/load.php' );
}
