<?php
/**
 * Plugin Name: Restrict Content Pro - Drip Content
 * Plugin URI: https://restrictcontentpro.com/downloads/drip-content/
 * Description: A drip content scheduling add-on for Restrict Content Pro.
 * Author: Sandhills Development, LLC
 * Author URI: https://sandhillsdev.com
 * Version: 1.0.7
 * Text Domain: rcp-drip-content
 * Domain Path: languages
 * iThemes Package: rcp-drip-content
 */
namespace RCP\Addon\DripContent;

defined( 'WPINC' ) or die;

define( 'RCP_DRIP_VERSION', '1.0.7' );
define( 'RCP_DRIP_DB_VERSION', 1.0 );
define( 'RCP_DRIP_PATH', plugin_dir_path( __FILE__ ) );
define( 'RCP_DRIP_URL', plugin_dir_url( __FILE__ ) );

/**
 * Loads the plugin files.
 */
function loader() {

	if ( ! defined( 'RCP_PLUGIN_VERSION' ) || version_compare( RCP_PLUGIN_VERSION, 2.6, '<' ) ) {
		add_action( 'admin_notices', '\RCP\Addon\DripContent\incompatible_version_notice' );
		return;
	}

	require_once RCP_DRIP_PATH . 'schedules/interface-drip-schedule-db.php';

	require_once RCP_DRIP_PATH . 'schedules/class-drip-schedule-db.php';

	require_once RCP_DRIP_PATH . 'helper-functions.php';

	require_once RCP_DRIP_PATH . 'settings/post-meta-box.php';

	require_once RCP_DRIP_PATH . 'settings/subscription-levels.php';

	require_once RCP_DRIP_PATH . 'visibility/drip-visibility-access.php';

	require_once RCP_DRIP_PATH . 'assets/load-scripts.php';

	require_once RCP_DRIP_PATH . 'shortcodes.php';
}
add_action( 'plugins_loaded', '\RCP\Addon\DripContent\loader' );

/**
 * Displays an admin notice if using an incompatible version of RCP core.
 */
function incompatible_version_notice() {
	echo '<div class="error"><p>' . __( 'Drip Content requires Restrict Content Pro version 2.6 or higher. Please upgrade Restrict Content Pro to the latest version.', 'rcp-drip-content' ) . '</p></div>';
}

/**
 * Runs the plugin activation routines.
 */
function plugin_activation() {
	require_once RCP_DRIP_PATH . 'system/activation.php';
	$activation = new \RCP\Addon\DripContent\System\Activation;
	$activation->tasks();
}
register_activation_hook( __FILE__, '\RCP\Addon\DripContent\plugin_activation' );

/**
 * Filters content visibility based on drip scheduling, if any.
 */
function rcp_drip_member_can_access() {
	if ( function_exists( 'rcp_get_membership' ) ) {
		add_filter( 'rcp_membership_can_access', '\RCP\Addon\DripContent\Visibility\membership_can_access', 100, 4 );
	} else {
		add_filter( 'rcp_member_can_access', '\RCP\Addon\DripContent\Visibility\can_access', 100, 4 );
	}
}
add_action( 'plugins_loaded', '\RCP\Addon\DripContent\rcp_drip_member_can_access', 10 );

/**
 * Loads the plugin translation files.
 */
function textdomain() {
	load_plugin_textdomain( 'rcp-drip-content', false, RCP_DRIP_PATH . 'languages' );
}
add_action( 'plugins_loaded', '\RCP\Addon\DripContent\textdomain' );

/**
 * Loads the plugin updater.
 */
function plugin_updater() {
	if ( is_admin() && class_exists( 'RCP_Add_On_Updater' ) ) {
		new \RCP_Add_On_Updater( 22326, __FILE__, RCP_DRIP_VERSION );
	}
}
add_action( 'plugins_loaded', '\RCP\Addon\DripContent\plugin_updater' );


if ( ! function_exists( 'ithemes_repository_name_updater_register' ) ) {
	function ithemes_repository_name_updater_register( $updater ) {
		$updater->register( 'rcp-drip-content', __FILE__ );
	}
	add_action( 'ithemes_updater_register', 'ithemes_repository_name_updater_register' );

	require( __DIR__ . '/lib/updater/load.php' );
}
