<?php
namespace RCP\Addon\DripContent\Settings;

defined( 'WPINC' ) or die;

function metabox_fields() {

	global $post, $wpdb;

	$db = new \RCP\Addon\DripContent\Schedules\Drip_Schedule_DB( array( 'post_id' => $post->ID ) );

	$schedules = $db->schedules_for_post();

	$schedules = ( ! empty( $schedules ) ) ? $schedules : array();

	?>

	<style>
		#rcp-drip-schedule-post-wrapper {
			border-top: 2px solid #ddd;
			margin-top: 30px;
			padding-top: 15px;
		}
		#rcp-drip-schedule-post-wrapper th {
			font-size: 13px;
			padding-bottom: 0;
		}
		.rcp-drip-schedule-post-row td:first-of-type {
			padding-left: 0;
		}
		.rcp-drip-schedule-post-remove {
			text-decoration: none;
			margin-top: 5px;
		}
	</style>

	<div id="rcp-drip-schedule-post-wrapper">
		<strong><?php _e( 'Drip Schedule', 'rcp-drip-content' ); ?></strong>

		<table class="form-table">
			<thead>
				<tr>
					<th scope="col"><?php _e( 'Membership Level', 'rcp-drip-content' ); ?></th>
					<th scope="col"><?php _e( 'Delay Access', 'rcp-drip-content' ); ?></th>
				</tr>
			</thead>

			<tbody>
				<?php
				if ( ! empty( $schedules ) ) :

					foreach( $schedules as $key => $schedule ) {
						do_action( 'rcp_render_drip_schedule_post_row', $key, $schedule );
					}
				else :
					do_action( 'rcp_render_drip_schedule_post_row', 0, array() );

				endif;
				?>
			</tbody>
		</table>
		<p><input name="rcp-drip-add-post-row" type="button" class="rcp-drip-schedule-post-add button" value="<?php _e( 'Add a Schedule', 'rcp-drip-content' ); ?>" /></p>
		<p class="description"><?php _e( 'The drip release schedule for this content. Optional. The drip schedule has no effect if you have no restrictions defined above.', 'rcp-drip-content' ); ?></p>
	</div>

	<?php
}
add_action( 'rcp_metabox_fields_after', '\RCP\Addon\DripContent\Settings\metabox_fields' );


function render_schedule_post_row( $key = '', array $schedule = array() ) {
	$defaults = array(
		'id'        => 0,
		'level_id'  => '',
		'type'      => 'post',
		'post_id'   => 'none',
		'unit'      => '',
		'period'    => 'none',
	);

	$schedule = wp_parse_args( $schedule, $defaults );

	$key = ! empty( $key ) ? absint( $key ) : 0;

	?>

	<tr id="rcp-drip-schedule-post-row-<?php echo $key; ?>" class="rcp-drip-schedule-post-row">
		<td>
			<select data-schedule-id="<?php echo absint( $schedule['id'] ); ?>" name="rcp-drip-settings-post[<?php echo $key; ?>][level_id]" class="rcp-drip-post-subscription-control">
				<option value="none" <?php selected( $schedule['level_id'], 'none' ); ?>><?php _e( 'None', 'rcp-drip-content' ); ?></option>
				<?php foreach ( rcp_get_subscription_levels() as $level_key => $level ) {
					echo '<option value="' . esc_attr( $level->id ) . '" ' . selected( $schedule['level_id'], $level->id ) . '">' . $level->name . '</option>';
				} ?>
			</select>
		</td>

		<td>

			<input data-schedule-id="<?php echo absint( $schedule['id'] ); ?>" type="number" name="rcp-drip-settings-post[<?php echo $key; ?>][unit]" id="rcp-drip-unit-<?php echo $key; ?>" value="<?php echo esc_attr( $schedule['unit'] ); ?>" style="width: 40px;" class="rcp-drip-post-unit-control" min="0" />

			<select data-schedule-id="<?php echo absint( $schedule['id'] ); ?>" name="rcp-drip-settings-post[<?php echo $key; ?>][period]" class="rcp-drip-post-period-control">
				<option value="none" <?php selected( $schedule['period'], 'none' ); ?>><?php _e( 'None', 'rcp-drip-content' ); ?></option>
				<option value="day" <?php selected( $schedule['period'], 'day' ); ?>><?php echo rcp_filter_duration_unit( 'day', 2 ); ?></option>
				<option value="month" <?php selected( $schedule['period'], 'month' ); ?>><?php echo rcp_filter_duration_unit( 'month', 2 ); ?></option>
				<option value="year" <?php selected( $schedule['period'], 'year' ); ?>><?php echo rcp_filter_duration_unit( 'year', 2 ); ?></option>
			</select>

			<input data-schedule-id="<?php echo absint( $schedule['id'] ); ?>" name="rcp-drip-settings-post[<?php echo $key; ?>][id]" type="hidden" class="rcp-drip-schedule-post-schedule-id" value="<?php echo absint( $schedule['id'] ); ?>" />
			<a href="#" class="rcp-drip-schedule-post-remove"><span name="rcp-drip-remove-row[[<?php echo $key; ?>]" class="dashicons dashicons-no rcp-drip-schedule-post-remove"></span></a>
		</td>
	</tr>

	<?php

}
add_action( 'rcp_render_drip_schedule_post_row', '\RCP\Addon\DripContent\Settings\render_schedule_post_row', 10, 2 );

/**
 * Saves the post drip schedule.
 */
function save_post_schedule( $post_id, $post, $update ) {

	if ( ! current_user_can( 'rcp_manage_levels' ) ) {
		return;
	}

	if ( ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) || ( defined( 'DOING_AJAX' ) && DOING_AJAX ) ) {
		return;
	}

	if ( 'auto-draft' === get_post_status( $post_id ) ) {
		return;
	}

	if ( in_array( $post->post_type, array( 'revision', 'nav_menu_item', 'attachment' ) ) ) {
		return;
	}

	if ( ! isset( $_POST['rcp-drip-settings-post'] ) ) {
		return;
	}

	$settings = ! empty( $_POST['rcp-drip-settings-post'] ) ? $_POST['rcp-drip-settings-post'] : array();

	$lowest_key = min( array_keys( $settings ) );

	if ( empty( $settings ) ) {
		$remove_all_db = new \RCP\Addon\DripContent\Schedules\Drip_Schedule_DB( array( 'post_id' => $post_id ) );
		$remove_all_db->delete_all_schedules_for_post();
		return;
	}

	$existing_db        = new \RCP\Addon\DripContent\Schedules\Drip_Schedule_DB( array( 'post_id' => $post_id ) );
	$existing_schedules = $existing_db->schedules_for_post();

	$schedule_ids = array();

	foreach ( $settings as $key => $setting ) {

		if ( isset( $setting['id'] ) ) {
			$schedule_ids[] = absint( $setting['id'] );
			$setting['id']  = absint( $setting['id'] );
		}

		$setting['type']      = 'post';
		$setting['post_type'] = $post->post_type;
		$setting['post_id']   = $post_id;
		$setting['unit']      = absint( $setting['unit'] );
		$setting['period']    = ( ! empty( $setting['period'] ) && in_array( $setting['period'], array( 'day', 'month', 'year' ) ) ) ? $setting['period'] : 'day';

		$setting_db = new \RCP\Addon\DripContent\Schedules\Drip_Schedule_DB( $setting );

		if ( ! empty( $setting['id'] ) && $setting_db->schedule_by_id() ) {
			$setting_db->update_schedule();
		} else {
			$setting_db->create_schedule();
		}
	}

	if ( ! empty( $existing_schedules ) ) {
		foreach( $existing_schedules as $existing_key => $existing_schedule ) {
			if ( ! in_array( $existing_schedule['id'], $schedule_ids ) ) {
				$remove_existing_db = new \RCP\Addon\DripContent\Schedules\Drip_Schedule_DB( $existing_schedule );
				$remove_existing_db->delete_schedule();
			}
		}
	}

}
add_action( 'save_post', '\RCP\Addon\DripContent\Settings\save_post_schedule', 10, 3 );

/**
 * Deletes associated drip schedules when a post is deleted.
 */
function delete_post_schedules( $post_id ) {

	if ( ! current_user_can( 'rcp_manage_levels' ) ) {
		return;
	}

	$db = new \RCP\Addon\DripContent\Schedules\Drip_Schedule_DB( array( 'post_id' => $post_id ) );
	$db->delete_all_schedules_for_post();
}
add_action( 'wp_trash_post', '\RCP\Addon\DripContent\Settings\delete_post_schedules' );