<?php
/**
 * Group Factory
 *
 * @package   rcp-group-accounts
 * @copyright Copyright (c) 2020, Sandhills Development, LLC
 * @license   GPL2+
 */

namespace RCPGA\Tests\Factories;

/**
 * Class Group_Factory
 *
 * @package RCPGA\Tests\Factories
 */
class Group_Factory extends \WP_UnitTest_Factory_For_Thing {

	/**
	 * @param array $args
	 * @param null  $generation_definitions
	 *
	 * @return \RCPGA_Group|false
	 */
	public function create_and_get( $args = array(), $generation_definitions = null ) {
		$generation_definitions = array(
			'name'        => new \WP_UnitTest_Generator_Sequence( 'Group Name %s' ),
			'description' => new \WP_UnitTest_Generator_Sequence( 'Group Description %s' )
		);

		return parent::create_and_get( $args, $generation_definitions );
	}

	/**
	 * @param array $args
	 *
	 * @return int|\WP_Error
	 */
	public function create_object( $args ) {

		if ( empty( $args['owner_id'] ) ) {
			// Create a new user.
			$user_factory = new \WP_UnitTest_Factory_For_User();
			$user_id      = $user_factory->create();

			if ( ! is_wp_error( $user_id ) ) {
				$args['owner_id'] = absint( $user_id );
			}
		}

		return rcpga_add_group( $args );

	}

	/**
	 * @param int   $object_id
	 * @param array $fields
	 *
	 * @return bool
	 */
	public function update_object( $object_id, $fields ) {
		return rcpga_update_group( $object_id, $fields );
	}

	/**
	 * @param int $object_id
	 *
	 * @return \RCPGA_Group|false
	 */
	public function get_object_by_id( $object_id ) {
		return rcpga_get_group( $object_id );
	}
}