<?php
/**
 * Group Member Factory
 *
 * @package   rcp-group-accounts
 * @copyright Copyright (c) 2020, Sandhills Development, LLC
 * @license   GPL2+
 */

namespace RCPGA\Tests\Factories;

/**
 * Class Group_Member_Factory
 *
 * @package RCPGA\Tests\Factories
 */
class Group_Member_Factory extends \WP_UnitTest_Factory_For_Thing {

	/**
	 * @param array $args
	 * @param null  $generation_definitions
	 *
	 * @return \RCPGA_Group_Member|false
	 */
	public function create_and_get( $args = array(), $generation_definitions = null ) {
		$generation_definitions = array(
			'role' => 'member'
		);

		return parent::create_and_get( $args, $generation_definitions );
	}

	/**
	 * @param array $args
	 *
	 * @return int|\WP_Error
	 */
	public function create_object( $args ) {

		if ( empty( $args['group_id'] ) ) {
			return new \WP_Error();
		}

		if ( empty( $args['user_id'] ) ) {
			// Create a new user.
			$user_factory = new \WP_UnitTest_Factory_For_User();
			$user_id      = $user_factory->create();

			if ( ! is_wp_error( $user_id ) ) {
				$args['user_id'] = absint( $user_id );
			}
		}

		return rcpga_add_group_member( $args['group_id'], $args );

	}

	/**
	 * @param int   $object_id
	 * @param array $fields
	 *
	 * @return bool
	 */
	public function update_object( $object_id, $fields ) {
		$member = $this->get_object_by_id( $object_id );

		if ( ! $member instanceof \RCPGA_Group_Member ) {
			return false;
		}

		return $member->update( $fields );
	}

	/**
	 * @param int $object_id
	 *
	 * @return \RCPGA_Group_Member|false
	 */
	public function get_object_by_id( $object_id ) {
		return rcpga_get_group_member_by_id( $object_id );
	}

}