<?php
/**
 * Plugin Name:     Restrict Content Pro - IP Restriction
 * Plugin URI:      https://restrictcontentpro.com/downloads/ip-restriction/
 * Description:     Adds support for restricting content by IP address
 * Version:         1.2.8
 * Author:          Sandhills Development, LLC
 * Author URI:      https://sandhillsdev.com
 * Text Domain:     rcp-ip-restriction
 * iThemes Package: rcp-ip-restriction
 *
 * @package         RCP\IP_Restriction
 * @author          Daniel J Griffiths <dgriffiths@section214.com>
 * @copyright       Copyright (c) 2015, Daniel J Griffiths
 */


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


if ( ! class_exists( 'RCP_IP_Restriction' ) ) {


	/**
	 * Main RCP_IP_Restriction class
	 *
	 * @since       1.0.0
	 */
	class RCP_IP_Restriction {


		/**
		 * @var         RCP_IP_Restriction $instance The one true RCP_IP_Restriction
		 * @since       1.0.0
		 */
		private static $instance;


		/**
		 * @var         bool $debugging Whether or not debugging is available
		 * @since       1.0.2
		 */
		public $debugging = false;


		/**
		 * @var         object $ipcheck The IPCheck class object
		 * @since       1.2.0
		 */
		public $ipcheck;


		/**
		 * Get active instance
		 *
		 * @access      public
		 * @since       1.0.0
		 * @return      object self::$instance The one true RCP_IP_Restriction
		 */
		public static function instance() {
			if ( ! self::$instance ) {
				self::$instance = new RCP_IP_Restriction();
				self::$instance->setup_constants();
				self::$instance->includes();
				self::$instance->load_textdomain();
				self::$instance->hooks();
				self::$instance->ipcheck = new IPCheck();

				if ( class_exists( 'S214_Debug' ) ) {
					$settings = get_option( 'rcp_ip_restriction_settings' );

					if ( isset( $settings['enable_debug'] ) ) {
						self::$instance->debugging = true;
					}
				}
			}

			return self::$instance;
		}


		/**
		 * Setup plugin constants
		 *
		 * @access      private
		 * @since       1.0.0
		 * @return      void
		 */
		public function setup_constants() {
			// Plugin version
			define( 'RCP_IP_RESTRICTION_VER', '1.2.8' );

			// Plugin path
			define( 'RCP_IP_RESTRICTION_DIR', plugin_dir_path( __FILE__ ) );

			// Plugin URL
			define( 'RCP_IP_RESTRICTION_URL', plugin_dir_url( __FILE__ ) );
		}


		/**
		 * Include necessary files
		 *
		 * @access      private
		 * @since       1.0.0
		 * @return      void
		 */
		private function includes() {
			require_once RCP_IP_RESTRICTION_DIR . 'includes/functions.php';
			require_once RCP_IP_RESTRICTION_DIR . 'includes/scripts.php';
			require_once RCP_IP_RESTRICTION_DIR . 'includes/filters.php';
			require_once RCP_IP_RESTRICTION_DIR . 'includes/actions.php';

			if ( is_admin() ) {
				require_once RCP_IP_RESTRICTION_DIR . 'includes/admin/settings/register.php';
				require_once RCP_IP_RESTRICTION_DIR . 'includes/admin/meta-box.php';
			}

			if ( ! class_exists( 'IPCheck' ) ) {
				require_once RCP_IP_RESTRICTION_DIR . 'includes/libraries/ipcheck.php';
			}
		}


		/**
		 * Run action and filter hooks
		 *
		 * @access      private
		 * @since       1.0.0
		 * @return      void
		 */
		private function hooks() {

			// Licensing
			if( class_exists( 'RCP_Add_On_Updater' ) ) {
				$updater = new RCP_Add_On_Updater( 340, __FILE__, RCP_IP_RESTRICTION_VER );
			}

		}


		/**
		 * Internationalization
		 *
		 * @access      public
		 * @since       1.0.0
		 * @return      void
		 */
		public static function load_textdomain() {
			// Set filter for language directory
			$lang_dir = dirname( plugin_basename( __FILE__ ) ) . '/languages/';
			$lang_dir = apply_filters( 'rcp_ip_restriction_languages_directory', $lang_dir );

			// Traditional WordPress plugin locale filter
			$locale = apply_filters( 'plugin_locale', get_locale(), 'rcp-ip-restriction' );
			$mofile = sprintf( '%1$s-%2$s.mo', 'rcp-ip-restriction', $locale );

			// Setup paths to current locale file
			$mofile_local  = $lang_dir . $mofile;
			$mofile_global = WP_LANG_DIR . '/rcp-ip-restriction/' . $mofile;

			if ( file_exists( $mofile_global ) ) {
				// Look in global /wp-content/languages/rcp-ip-restriction/ folder
				load_textdomain( 'rcp-ip-restriction', $mofile_global );
			} elseif ( file_exists( $mofile_local ) ) {
				// Look in local /wp-content/plugins/rcp-ip-restriction/languages/ folder
				load_textdomain( 'rcp-ip-restriction', $mofile_local );
			} else {
				// Load the default language files
				load_plugin_textdomain( 'rcp-ip-restriction', false, $lang_dir );
			}
		}
	}
}


/**
 * The main function responsible for returning the one true RCP_IP_Restriction
 * instance to functions everywhere
 *
 * @since       1.0.0
 * @return      RCP_IP_Restriction The one true RCP_IP_Restriction
 */
function rcp_ip_restriction() {
	return RCP_IP_Restriction::instance();
}
add_action( 'plugins_loaded', 'rcp_ip_restriction' );


if ( ! function_exists( 'ithemes_repository_name_updater_register' ) ) {
	function ithemes_repository_name_updater_register( $updater ) {
		$updater->register( 'rcp-ip-restriction', __FILE__ );
	}
	add_action( 'ithemes_updater_register', 'ithemes_repository_name_updater_register' );

	require( __DIR__ . '/lib/updater/load.php' );
}
