<?php
/**
 * Single IP Address
 *
 * Test that we can match single IP address entries in the whitelist.
 *
 * Example: `127.0.0.1` on whitelist so IP `127.0.0.1` should match.
 *
 * @package   rcp-ip-restriction
 * @copyright Copyright (c) 2020, Sandhills Development, LLC
 * @license   GPL2+
 */

namespace RCP_IP_Restriction\Tests;

/**
 * Class Test_IP_Single
 *
 * @package RCP_IP_Restriction\Tests
 */
class Test_IP_Single extends UnitTestCase {

	/**
	 * Set up once before tests are run
	 */
	public static function setUpBeforeClass() {
		parent::setUpBeforeClass();

		// Update global whitelist.
		$settings = array(
			'whitelist' => array(
				'127.0.0.1', // Single IP
				'127.0.0.2'
			)
		);

		update_option( 'rcp_ip_restriction_settings', $settings );
	}

	/**
	 * IPs not on the whitelist should not be allowed.
	 *
	 * @covers ::rcp_ip_restriction_is_whitelisted()
	 */
	public function test_ip_not_on_global_whitelist_not_whitelisted() {

		self::$ip = '170.250.174.235';

		$this->assertFalse( rcp_ip_restriction_is_whitelisted( self::$post->ID ) );

		self::$ip = '127.0.0.5';

		$this->assertFalse( rcp_ip_restriction_is_whitelisted( self::$post->ID ) );

	}

	/**
	 * IPs that are on the whitelist should be allowed.
	 *
	 * @covers ::rcp_ip_restriction_is_whitelisted()
	 */
	public function test_single_ip_on_global_whitelist_is_whitelisted() {

		self::$ip = '127.0.0.1';

		$this->assertTrue( rcp_ip_restriction_is_whitelisted( self::$post->ID ) );

		self::$ip = '127.0.0.2';

		$this->assertTrue( rcp_ip_restriction_is_whitelisted( self::$post->ID ) );

	}

}
