<?php
/**
 * Base Exception
 *
 * @package   rcp-mailchimp-pro
 * @copyright Copyright (c) 2020, Sandhills Development, LLC
 * @license   GPL2+
 * @since     1.5
 */

namespace RCP\MailChimp_Pro\Exceptions;

use Exception;
use WP_Error;

/**
 * Class Base
 *
 * @package RCP\MailChimp_Pro\Exceptions
 */
abstract class Base extends Exception {

	/**
	 * @var WP_Error
	 */
	protected $wp_error;

	/**
	 * @var int|null
	 */
	protected $http_code;

	/**
	 * Base constructor.
	 *
	 * @param WP_Error|null $error
	 */
	public function __construct( $error = null, $http_code = null ) {

		$this->wp_error  = $error instanceof WP_Error ? $error : new WP_Error();
		$message         = $error instanceof WP_Error ? $error->get_error_message() : '';
		$this->http_code = $http_code;
		$error_code      = is_int( $http_code ) ? $http_code : 0;

		parent::__construct( $message, $error_code );
	}

	/**
	 * Retrieves the WP_Error object
	 *
	 * @since 1.5
	 * @return WP_Error|null
	 */
	public function get_wp_error() {
		return $this->wp_error;
	}

	/**
	 * Retrieves the HTTP response code
	 *
	 * @since 1.5
	 * @return int|null
	 */
	public function get_http_code() {
		return $this->http_code;
	}

}