<?php
/**
 * Plugin Name: Restrict Content Pro - Math Verification
 * Plugin URL: http://restrictcontentpro.com/downloads/math-verification/
 * Description: Adds a simple math captcha to the Restrict Content Pro registration form
 * Version: 1.0.5
 * Author: Sandhills Development, LLC
 * Author URI: https://sandhillsdev.com
 * Text Domain: rcp-math-verification
 * iThemes Package: rcp-math-verification
 */

/**
 * Add support for automatic updates.
 *
 * @since 1.0
 * @return void
 */
function rcp_math_updater() {

	if( is_admin() && class_exists( 'RCP_Add_On_Updater' ) ) {
		$updater = new RCP_Add_On_Updater( 52, __FILE__, '1.0.5' );
	}

}
add_action(' plugins_loaded', 'rcp_math_updater' );

/**
 * Displays the math verification fields on the registration form.
 *
 * @since 1.0
 * @return void
 */
function rcp_math_fields() {
	global $rcp_options;
	$math_one = rand(0,10);
	$math_two = rand(0,10);
	$label = isset($rcp_options['math_label']) && $rcp_options['math_label'] != '' ? $rcp_options['math_label'] : __('What does this equal?:', 'rcp-math-verification');
	ob_start(); ?>
		<p>
			<input id="rcp_math_1" type="hidden" name="rcp_math_1" value="<?php echo esc_attr( $math_one ); ?>"/>
			<input id="rcp_math_2" type="hidden" name="rcp_math_2" value="<?php echo esc_attr( $math_two ); ?>"/>
			<label for="rcp_math_one"><?php echo $label . ' ' . $math_one . ' + ' . $math_two; ?></label>
			<input id="rcp_math_answer" type="text" name="rcp_math_answer" value="" class="required"/>
		</p>
		<?php
	echo ob_get_clean();
}
add_action('rcp_before_registration_submit_field', 'rcp_math_fields', 0);

/**
 * Check if the math answer is correct. Show error message if not.
 *
 * @param array $posted
 *
 * @since 1.0
 * @return void
 */
function rcp_verify_math( $posted ) {

	if( ! empty( $_POST['rcp_stripe_checkout'] ) ) {
		return;
	}

	if( ! isset( $posted['rcp_math_1'] ) || ! isset( $posted['rcp_math_2'] ) || ! isset( $posted['rcp_math_answer'] ) ) {
		rcp_errors()->add( 'do_math', __( 'Please answer the math question', 'rcp-math-verification'), 'register' );
	}

	if( ! is_numeric( $posted['rcp_math_1'] ) || ! is_numeric( $posted['rcp_math_2'] ) || ! is_numeric( $posted['rcp_math_answer'] ) ) {
		rcp_errors()->add( 'do_math', __( 'Please only enter numbers in the math fields', 'rcp-math-verification'), 'register' );
	}

	$result = $posted['rcp_math_1'] + $posted['rcp_math_2'];
	$answer = $posted['rcp_math_answer'];

	if( $result != $answer ) {
		rcp_errors()->add( 'incorrect_math', __( 'Your math is incorrect', 'rcp-math-verification'), 'register' );
	}
}
add_action( 'rcp_form_errors', 'rcp_verify_math' );

/**
 * Maybe display math field on login form.
 *
 * @since 1.0.3
 * @return void
 */
function rcp_math_fields_login_form() {

	global $rcp_options;

	if ( empty( $rcp_options['math_login'] ) ) {
		return;
	}

	$math_one = rand(0,10);
	$math_two = rand(0,10);
	$label    = ! empty( $rcp_options['math_label'] ) ? $rcp_options['math_label'] : __( 'What does this equal?:', 'rcp-math-verification' );
	?>
	<p>
		<input id="rcp_math_1" type="hidden" name="rcp_math_1" value="<?php echo esc_attr( $math_one ); ?>"/>
		<input id="rcp_math_2" type="hidden" name="rcp_math_2" value="<?php echo esc_attr( $math_two ); ?>"/>
		<label for="rcp_math_one"><?php echo $label . ' ' . $math_one . ' + ' . $math_two; ?></label>
		<input id="rcp_math_answer" type="text" name="rcp_math_answer" value="" class="required"/>
	</p>
	<?php

}
add_action( 'rcp_login_form_fields_before_submit', 'rcp_math_fields_login_form' );

/**
 * Process math field during login.
 *
 * @param array $posted
 *
 * @since 1.0.3
 * @return void
 */
function rcp_math_process_login_form( $posted ) {

	global $rcp_options;

	if ( empty( $rcp_options['math_login'] ) ) {
		return;
	}

	if( ! isset( $posted['rcp_math_1'] ) || ! isset( $posted['rcp_math_2'] ) || ! isset( $posted['rcp_math_answer'] ) ) {
		rcp_errors()->add( 'do_math', __( 'Please answer the math question', 'rcp-math-verification' ), 'login' );
	}

	if( ! is_numeric( $posted['rcp_math_1'] ) || ! is_numeric( $posted['rcp_math_2'] ) || ! is_numeric( $posted['rcp_math_answer'] ) ) {
		rcp_errors()->add( 'do_math', __( 'Please only enter numbers in the math fields', 'rcp-math-verification' ), 'login' );
	}

	$result = $posted['rcp_math_1'] + $posted['rcp_math_2'];
	$answer = $posted['rcp_math_answer'];

	if( $result != $answer ) {
		rcp_errors()->add( 'incorrect_math', __( 'Your math is incorrect', 'rcp-math-verification' ), 'login' );
	}

}
add_action( 'rcp_login_form_errors', 'rcp_math_process_login_form' );

/**
 * Add new setting for the math label.
 *
 * @param array $rcp_options Saved plugin settings.
 *
 * @since 1.0
 * @return void
 */
function rcp_add_math_label_setting( $rcp_options ) {
	?>
	<table class="form-table">
		<tr valign="top">
			<th>
				<label for="rcp_settings[math_label]"><?php _e( 'Math Label', 'rcp-math-verification' ); ?></label>
			</th>
			<td>
				<input id="rcp_settings[math_label]" style="width: 300px;" name="rcp_settings[math_label]" type="text" value="<?php if( isset( $rcp_options['math_label'] ) ) echo esc_attr( $rcp_options['math_label'] ); ?>" />
				<div class="description"><?php _e('Enter the text shown next to the simple math verification field. Default: "What does this equal?:"', 'rcp-math-verification'); ?></div>
			</td>
		</tr>
		<tr valign="top">
			<th>
				<label for="rcp_settings[math_login]"><?php _e( 'Math Verification on Login', 'rcp-math-verification' ); ?></label>
			</th>
			<td>
				<input id="rcp_settings[math_login]" name="rcp_settings[math_login]" type="checkbox" value="1" <?php checked( ! empty( $rcp_options['math_login'] ) ); ?> />
				<span class="description"><?php _e('Check to add math verification to the login form.', 'rcp-math-verification' ); ?></span>
			</td>
		</tr>
	</table>
	<?php
}
add_action( 'rcp_misc_settings', 'rcp_add_math_label_setting' );

/**
 * Load plugin text domain for translations
 *
 * @since 1.0.3
 * @return void
 */
function rcp_math_load_textdomain() {

	// Set filter for plugin's languages directory
	$lang_dir = dirname( plugin_basename( __FILE__ ) ) . '/languages/';

	// Load the translations
	load_plugin_textdomain( 'rcp-math-verification', false, $lang_dir );

}
add_action( 'init', 'rcp_math_load_textdomain' );


if ( ! function_exists( 'ithemes_repository_name_updater_register' ) ) {
	function ithemes_repository_name_updater_register( $updater ) {
		$updater->register( 'rcp-math-verification', __FILE__ );
	}
	add_action( 'ithemes_updater_register', 'ithemes_repository_name_updater_register' );

	require( __DIR__ . '/lib/updater/load.php' );
}
