<?php
/**
 * Plugin Name: Restrict Content Pro - Restrict Past Content
 * Description: Restricts access to content published prior to a membership's start date, allowing the customer to access only content published on or after their start date.
 * Author: Sandhills Development, LLC
 * Author URI: https://sandhillsdev.com
 * Version: 1.0.3
 * Text Domain: rcp-restrict-past-content
 * Domain Path: languages
 * iThemes Package: rcp-restrict-past-content
 */
namespace RCP\Addon\RestrictPastContent;

defined( 'WPINC' ) or die;

define( 'RCP_RESTRICT_PAST_CONTENT_VERSION', '1.0.3' );
define( 'RCP_RESTRICT_PAST_CONTENT_PATH', plugin_dir_path( __FILE__ ) );
define( 'RCP_RESTRICT_PAST_CONTENT_URL', plugin_dir_url( __FILE__ ) );

/**
 * Loads the plugin files.
 */
function loader() {

	if ( ! defined( 'RCP_PLUGIN_VERSION' ) || version_compare( RCP_PLUGIN_VERSION, 2.6, '<' ) ) {
		add_action( 'admin_notices', '\RCP\Addon\RestrictPastContent\incompatible_version_notice' );
		return;
	}
	require_once RCP_RESTRICT_PAST_CONTENT_PATH . 'settings/subscription-levels.php';
	require_once RCP_RESTRICT_PAST_CONTENT_PATH . 'settings/post-meta-box.php';
	require_once RCP_RESTRICT_PAST_CONTENT_PATH . 'visibility.php';
}
add_action( 'plugins_loaded', '\RCP\Addon\RestrictPastContent\loader' );

/**
 * Displays an admin notice if using an incompatible version of RCP core.
 */
function incompatible_version_notice() {
	echo '<div class="error"><p>' . __( 'Restrict Past Content requires Restrict Content Pro version 2.6 or higher. Please upgrade Restrict Content Pro to the latest version.', 'rcp-restrict-past-content' ) . '</p></div>';
}

/**
 * Filters content visibility.
 *
 * This only adds the filter for versions 2.9 and lower. Version 3.0 uses a new filter handled by `membership_can_access()`
 * @see membership_can_access()
 */
function init_visibility_filter() {
	if ( ! function_exists( 'rcp_get_membership' ) ) {
		add_filter( 'rcp_member_can_access', '\RCP\Addon\RestrictPastContent\can_access', 100, 4 );
	}
}
add_action( 'plugins_loaded', '\RCP\Addon\RestrictPastContent\init_visibility_filter' );

/**
 * Loads the plugin translation files.
 */
function textdomain() {
	load_plugin_textdomain( 'rcp-restrict-past-content', false, RCP_RESTRICT_PAST_CONTENT_PATH . 'languages' );
}
add_action( 'plugins_loaded', '\RCP\Addon\RestrictPastContent\textdomain' );

/**
 * Loads the plugin updater.
 */
function plugin_updater() {
	if ( is_admin() && class_exists( 'RCP_Add_On_Updater' ) ) {
		new \RCP_Add_On_Updater( 22083, __FILE__, RCP_RESTRICT_PAST_CONTENT_VERSION );
	}
}
add_action( 'plugins_loaded', '\RCP\Addon\RestrictPastContent\plugin_updater' );

/**
 * Removes the subscription meta when the level is deleted.
 */
function remove_meta( $id ) {
	global $rcp_levels_db;
	$rcp_levels_db->delete_meta( $id, 'restrict_past_content' );
	$rcp_levels_db->delete_meta( $id, 'restrict_past_content_offset' );
}
add_action( 'rcp_remove_level', '\RCP\Addon\RestrictPastContent\remove_meta' );


if ( ! function_exists( 'ithemes_repository_name_updater_register' ) ) {
	function ithemes_repository_name_updater_register( $updater ) {
		$updater->register( 'rcp-restrict-past-content', __FILE__ );
	}
	add_action( 'ithemes_updater_register', 'ithemes_repository_name_updater_register' );

	require( __DIR__ . '/lib/updater/load.php' );
}
