<?php

namespace RCP\Addon\RestrictPastContent;

defined( 'WPINC' ) or die;

/**
 * Displays the meta box on the post edit screen.
 */
function metabox_fields() {

	global $post, $rcp_levels_db;
	?>

	<div class="rcp-metabox-field">

		<p><strong><?php _e( 'Exclude from Past Content Restrictions', 'rcp-restrict-past-content' ); ?></strong></p>
		<p>
			<label for="rcp_restrict_past_content_exclude">
				<input type="checkbox" id="rcp_restrict_past_content_exclude" name="rcp_restrict_past_content_exclude" value="1" <?php checked( true, get_post_meta( $post->ID, 'rcp_restrict_past_content_exclude', true ) ); ?>/>
				<?php _e( 'Check this box to exclude this content from the restrictions imposed by the Restrict Past Content add-on.', 'rcp-restrict-past-content' ); ?>
			</label>
		</p>
	</div>
	<?php
}
add_action( 'rcp_metabox_fields_after', '\RCP\Addon\RestrictPastContent\metabox_fields' );


/**
 * Handles the post meta exclusion setting.
 */
function save_post( $post_id, $post ) {

	if ( ! current_user_can( 'rcp_manage_levels' ) ) {
		return;
	}

	if ( ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) || ( defined( 'DOING_AJAX' ) && DOING_AJAX ) ) {
		return;
	}

	if ( 'auto-draft' === get_post_status( $post_id ) ) {
		return;
	}

	if ( in_array( $post->post_type, array( 'revision', 'nav_menu_item', 'attachment' ) ) ) {
		return;
	}

	if ( ! isset( $_POST['rcp_restrict_past_content_exclude'] ) ) {
		delete_post_meta( $post_id, 'rcp_restrict_past_content_exclude', '1' );
		return;
	}

	update_post_meta( $post_id, 'rcp_restrict_past_content_exclude', true );
}
add_action( 'save_post', '\RCP\Addon\RestrictPastContent\save_post', 10, 2 );

/**
 * Deletes the exclusion setting when a post is deleted.
 */
function delete_post( $post_id ) {

	if ( ! current_user_can( 'rcp_manage_levels' ) ) {
		return;
	}

	delete_post_meta( $post_id, 'rcp_restrict_past_content_exclude' );
}
add_action( 'wp_trash_post', '\RCP\Addon\RestrictPastContent\delete_post' );