<?php
/**
 * Add taxonomy fields
 *
 * @package     RCP\Restriction_Timeouts\Admin\Settings\Taxonomies
 * @since       1.0.0
 */


// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Setup actions for taxonomy restricted fields
 *
 * @since       1.0.0
 * @return      void
 */
function rcp_restriction_timeouts_setup_taxonomy_edit_fields() {
	$taxonomies = rcp_get_restricted_taxonomies();

	foreach( $taxonomies as $taxonomy ) {
		add_action( "{$taxonomy}_edit_form_fields", 'rcp_restriction_timeouts_category_edit_meta_fields' );
	}
}
add_action( 'admin_init', 'rcp_restriction_timeouts_setup_taxonomy_edit_fields' );


/**
 * Add restriction timeout to the edit category page
 *
 * @since       1.0.0
 * @return      void
 */
function rcp_restriction_timeouts_category_edit_meta_fields( $term ) {
	$timeout = rcp_restriction_timeouts_get_term_timeout( $term->term_id );
	$timeout_was = rcp_restriction_timeouts_get_past_term_timeout( $term->term_id );
	$taxonomy = ( isset( $_GET['taxonomy'] ) ? $_GET['taxonomy'] : __( 'category', 'rcp-restriction-timeouts' ) );
	?>
	<tr>
		<th scope="row"><?php _e( 'Restriction Timeout', 'rcp-restriction-timeouts' ); ?></th>
		<td>
			<label for="rcp_timeout">
				<input type="text" name="rcp_timeout" id="rcp_timeout" value="<?php echo esc_attr( $timeout ); ?>" />
				<?php printf( __( 'Choose when this %s should become unrestricted.', 'rcp-restriction-timeouts' ), $taxonomy ); ?>
			</label>
		</td>
	</tr>
	<?php if( $timeout_was ) : ?>
		<tr>
			<th scope="rpw"><?php _e( 'Restriction Timeout Was:', 'rcp-restriction-timeouts' ); ?></th>
			<td >
				<span><?php echo esc_html( $timeout_was ); ?></span>
			</td>
		</tr>
	<?php endif; ?>
<?php
}


/**
 * Save our custom category meta
 *
 * @since       1.0.0
 * @param       int $term_id The ID of this term
 * @return      void
 */
function rcp_restriction_timeouts_save_category_meta( $term_id, $tt_id, $taxonomy ) {
	if( empty( $_POST['rcp_edit_term'] ) || ! wp_verify_nonce( $_POST['rcp_edit_term'], 'rcp_edit_term' ) ) {
		return;
	}

	$restricted_taxonomies = rcp_get_restricted_taxonomies();
	if( ! in_array( $taxonomy, $restricted_taxonomies ) ) {
		return;
	}

	$timeout = ! empty( $_POST['rcp_timeout'] ) ? sanitize_text_field( $_POST['rcp_timeout'] ) : false;

	if ( ! empty( $timeout ) ) {
		if ( function_exists( 'update_term_meta' ) && update_term_meta( $term_id, 'rcp_timeout', $timeout ) ) {
			// Remove deprecated data
			delete_option( "rcp_timeout_$term_id" );
		} else {
			// fallback to older method of handling term meta
			update_option( "rcp_timeout_$term_id", $timeout );
		}
	} else {
		if ( function_exists( 'delete_term_meta' ) ) {
			delete_term_meta( $term_id, 'rcp_timeout' );
		} else {
			delete_option( "rcp_timeout_$term_id" );
		}
	}

}
add_action( 'edited_term', 'rcp_restriction_timeouts_save_category_meta', 10, 3 );
