<?php
/**
 * Plugin Name:     Restrict Content Pro - Restriction Timeouts
 * Plugin URI:      https://restrictcontentpro.com
 * Description:     Set automatic timeouts for restricted content with RCP
 * Version:         1.0.5
 * Author:          Sandhills Development, LLC
 * Author URI:      https://sandhillsdev.com
 * Text Domain:     rcp-restriction-timeouts
 * iThemes Package: rcp-restriction-timeouts
 *
 * @package         RCP\Restriction_Timeouts
 * @author          Daniel J Griffiths <dgriffiths@section214.com>
 * @copyright       Copyright (c) 2016, Daniel J Griffiths
 */


// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) {
	exit;
}


if( ! class_exists( 'RCP_Restriction_Timeouts' ) ) {


	/**
	 * Main RCP_Restriction_Timeouts class
	 *
	 * @since       1.0.0
	 */
	class RCP_Restriction_Timeouts {


		/**
		 * @var         RCP_Restriction_Timeouts $instance The one true RCP_Restriction_Timeouts
		 * @since       1.0.0
		 */
		private static $instance;


		/**
		 * Get active instance
		 *
		 * @access      public
		 * @since       1.0.0
		 * @return      object self::$instance The one true RCP_Restriction_Timeouts
		 */
		public static function instance() {
			if( ! self::$instance ) {
				self::$instance = new RCP_Restriction_Timeouts();
				self::$instance->setup_constants();
				self::$instance->updater();
				self::$instance->includes();
				self::$instance->load_textdomain();
			}

			return self::$instance;
		}


		/**
		 * Setup plugin constants
		 *
		 * @access      private
		 * @since       1.0.0
		 * @return      void
		 */
		public function setup_constants() {
			// Plugin version
			define( 'RCP_RESTRICTION_TIMEOUTS_VER', '1.0.5' );

			// Plugin path
			define( 'RCP_RESTRICTION_TIMEOUTS_DIR', plugin_dir_path( __FILE__ ) );

			// Plugin URL
			define( 'RCP_RESTRICTION_TIMEOUTS_URL', plugin_dir_url( __FILE__ ) );
		}

		/**
		 * Load our updater
		 *
		 * @access      private
		 * @since       1.0.0
		 * @return      void
		 */
		private function updater() {

			if( class_exists( 'RCP_Add_On_Updater' ) ) {
				$updater = new RCP_Add_On_Updater( 18205, __FILE__, RCP_RESTRICTION_TIMEOUTS_VER );
			}

		}

		/**
		 * Include necessary files
		 *
		 * @access      private
		 * @since       1.0.0
		 * @return      void
		 */
		private function includes() {
			if ( ! defined( 'RCP_PLUGIN_DIR' ) ) {
				return;
			}
			require_once RCP_RESTRICTION_TIMEOUTS_DIR . 'includes/scripts.php';
			require_once RCP_RESTRICTION_TIMEOUTS_DIR . 'includes/functions.php';
			require_once RCP_RESTRICTION_TIMEOUTS_DIR . 'includes/cron-functions.php';

			if( is_admin() ) {
				require_once RCP_RESTRICTION_TIMEOUTS_DIR . 'includes/admin/metabox.php';
				require_once RCP_RESTRICTION_TIMEOUTS_DIR . 'includes/admin/taxonomies.php';
			}
		}

		/**
		 * Internationalization
		 *
		 * @access      public
		 * @since       1.0.0
		 * @return      void
		 */
		public static function load_textdomain() {
			// Set filter for language directory
			$lang_dir = dirname( plugin_basename( __FILE__ ) ) . '/languages/';
			$lang_dir = apply_filters( 'rcp_restriction_timeouts_languages_directory', $lang_dir );

			// Traditional WordPress plugin locale filter
			$locale = apply_filters( 'plugin_locale', get_locale(), 'rcp-restriction-timeouts' );
			$mofile = sprintf( '%1$s-%2$s.mo', 'rcp-restriction-timeouts', $locale );

			// Setup paths to current locale file
			$mofile_local  = $lang_dir . $mofile;
			$mofile_global = WP_LANG_DIR . '/rcp-restriction-timeouts/' . $mofile;

			if( file_exists( $mofile_global ) ) {
				// Look in global /wp-content/languages/rcp-restriction-timeouts/ folder
				load_textdomain( 'rcp-restriction-timeouts', $mofile_global );
			} elseif( file_exists( $mofile_local ) ) {
				// Look in local /wp-content/plugins/rcp-restriction-timeouts/languages/ folder
				load_textdomain( 'rcp-restriction-timeouts', $mofile_local );
			} else {
				// Load the default language files
				load_plugin_textdomain( 'rcp-restriction-timeouts', false, $lang_dir );
			}
		}
	}
}


/**
 * The main function responsible for returning the one true RCP_Restriction_Timeouts
 * instance to functions everywhere
 *
 * @since       1.0.0
 * @return      RCP_Restriction_Timeouts The one true RCP_Restriction_Timeouts
 */
function rcp_restriction_timeouts() {
	return RCP_Restriction_Timeouts::instance();
}
add_action( 'plugins_loaded', 'rcp_restriction_timeouts' );


if ( ! function_exists( 'ithemes_repository_name_updater_register' ) ) {
	function ithemes_repository_name_updater_register( $updater ) {
		$updater->register( 'rcp-restriction-timeouts', __FILE__ );
	}
	add_action( 'ithemes_updater_register', 'ithemes_repository_name_updater_register' );

	require( __DIR__ . '/lib/updater/load.php' );
}
