<?php
/**
 * Actions
 *
 * @package     RCP\Site_Creation\Actions
 * @since       1.0.0
 */


// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Add the subsite field to the registration form
 *
 * @since       1.0.0
 * @return      void
 */
function rcp_site_creation_registration_fields() {
	ob_start();

	$show_fields = ! is_user_logged_in() || ! rcp_site_creation_get_user_blog( get_current_user_id() );

	if ( function_exists( 'rcp_multiple_memberships_enabled' ) && rcp_multiple_memberships_enabled() && method_exists( rcp_get_registration(), 'get_registration_type' ) ) {
		/*
		 * When multiple memberships are activated, we only want to (maybe) show the site creation fields if this is
		 * a brand new registration. They do not need to appear on renewals or upgrades/downgrades.
		 */
		$show_fields = ( 'new' == rcp_get_registration()->get_registration_type() );
	}

    if( $show_fields ) {
		$settings = get_option( 'rcp_site_creation_settings' );
		$schemes  = ( ! empty( $settings['domain_mapping_schemes'] ) && is_array( $settings['domain_mapping_schemes'] ) ) ? $settings['domain_mapping_schemes'] : array( 'http' );
?>
		<div id="rcp_site_creation_fields_wrap">
			<p id="rcp_site_creation_url_wrap">
				<label for="rcp_site_creation_url"><?php echo ( isset( $settings['url_field_title'] ) && ! empty( $settings['url_field_title'] ) ? $settings['url_field_title'] : __( 'Subsite URL', 'rcp-site-creation' ) ); ?></label>
				<?php if ( ! empty( $settings['domain_mapping'] ) ) :
					if ( count( $schemes ) > 1 ) : ?>
					<select id="rcp_site_creation_url_scheme" name="rcp_site_creation_url_scheme">
						<option value="https"><?php _e( 'https://', 'rcp-site-creation' ); ?></option>
						<option value="http"><?php _e( 'http://', 'rcp-site-creation' ); ?></option>
					</select>
					<?php else : ?>
						<span id="rcp_site_creation_url_prefix"><?php echo $schemes[0] . '://'; ?></span>
						<input type="hidden" id="rcp_site_creation_url_scheme" name="rcp_site_creation_url_scheme" value="<?php echo esc_attr( $schemes[0] ); ?>">
					<?php endif; ?>
				<?php endif; ?>
				<input id="rcp_site_creation_url" name="rcp_site_creation_url" type="text" value="<?php echo ( isset( $_POST['rcp_site_creation_url'] ) ? $_POST['rcp_site_creation_url'] : '' ); ?>" />
				<span class="rcp_site_creation_url_preview_wrap" style="display: none"><span class="rcp_site_creation_url_preview_label"><?php _e( 'Preview:', 'rcp-site-creation' ); ?></span>&nbsp;<code><span class="rcp_site_creation_url_preview_subdomain"></span></code></span>
			</p>

			<p id="rcp_site_creation_name_wrap">
				<label for="rcp_site_creation_name"><?php echo ( isset( $settings['name_field_title'] ) && ! empty( $settings['name_field_title'] ) ? $settings['name_field_title'] : __( 'Subsite Name', 'rcp-site-creation' ) ); ?></label>
				<input id="rcp_site_creation_name" name="rcp_site_creation_name" type="text" value="<?php echo ( isset( $_POST['rcp_site_creation_name'] ) ? $_POST['rcp_site_creation_name'] : '' ); ?>" />
			</p>

			<?php if( ! empty( $settings['desc_field_show'] ) ) : ?>
				<p id="rcp_site_creation_desc_wrap">
					<label for="rcp_site_creation_desc"><?php echo ( isset( $settings['desc_field_title'] ) && ! empty( $settings['desc_field_title'] ) ? $settings['desc_field_title'] : __( 'Subsite Description', 'rcp-site-creation' ) ); ?></label>
					<input id="rcp_site_creation_desc" name="rcp_site_creation_desc" type="text" value="<?php echo ( isset( $_POST['rcp_site_creation_desc'] ) ? $_POST['rcp_site_creation_desc'] : '' ); ?>" />
				</p>
			<?php endif; ?>

			<?php
			/**
			 * Fires immediately after the site creation registration fields are rendered.
			 *
			 * @since 1.2
			 *
			 * @param array $settings RCP Site Creation settings.
			 */
			do_action( 'rcp_site_creation_registration_fields', $settings ); ?>
		</div>
<?php
	}

	echo ob_get_clean();
}
add_action( 'rcp_after_register_form_fields', 'rcp_site_creation_registration_fields', 100 );


/**
 * Add error on registration form for unavailable URLs
 *
 * @since       1.0.0
 * @param       object $post The WordPress post object
 * @return      void
 */
function rcp_site_creation_registration_errors( $post ) {
	$show_fields = ! is_user_logged_in() || ! rcp_site_creation_get_user_blog( get_current_user_id() );

	if ( function_exists( 'rcp_multiple_memberships_enabled' ) && rcp_multiple_memberships_enabled() && method_exists( rcp_get_registration(), 'get_registration_type' ) ) {
		/*
		 * When multiple memberships are activated, we only want to (maybe) show the site creation fields if this is
		 * a brand new registration. They do not need to appear on renewals or upgrades/downgrades.
		 */
		$show_fields = ( 'new' == rcp_get_registration()->get_registration_type() );
	}

	if( $show_fields ) {

		// Double check if the selected level is allowed to create sites
		if( isset( $_POST['rcp_level'] ) ) {
			if( ! rcp_site_creation_allowed( $_POST['rcp_level'] ) && isset( $_POST['rcp_site_creation_url'] ) && $_POST['rcp_site_creation_url'] !== '' ) {
				$_POST['rcp_site_creation_url'] = '';
			} elseif( rcp_site_creation_allowed( $_POST['rcp_level'] ) ) {
				$settings = get_option( 'rcp_site_creation_settings' );

				// URL is required!
				if( ! isset( $_POST['rcp_site_creation_url'] ) || $_POST['rcp_site_creation_url'] == '' || ! isset( $_POST['rcp_site_creation_name'] ) || $_POST['rcp_site_creation_name'] == '' ) {
					if( ! isset( $_POST['rcp_site_creation_url'] ) || $_POST['rcp_site_creation_url'] == '' ) {
						if( isset( $settings['subsite_required_error'] ) ) {
							$subsite_required_error = $settings['subsite_required_error'];
						} else {
							$subsite_required_error = __( 'The subsite URL field is required, please try again.', 'rcp-site-creation' );
						}

						rcp_errors()->add( 'subsite_required_error', $subsite_required_error, 'register' );
					}

					if( ! isset( $_POST['rcp_site_creation_name'] ) || $_POST['rcp_site_creation_name'] == '' ) {
						if( isset( $settings['name_required_error'] ) ) {
							$name_required_error = $settings['name_required_error'];
						} else {
							$name_required_error = __( 'The subsite name field is required, please try again.', 'rcp-site-creation' );
						}

						rcp_errors()->add( 'name_required_error', $name_required_error, 'register' );
					}
				} else {
					// Make sure the URL is available
					$subsite = rcp_site_creation_sanitize_url( $_POST['rcp_site_creation_url'] );

					if( rcp_site_creation_get_id_from_blogname( $subsite ) || ( ! is_subdomain_install() && isset( $settings['safe_urls'] ) && get_page_by_path( $subsite ) ) ) {
						if( isset( $settings['subsite_exists_error'] ) ) {
							$subsite_exists_error = $settings['subsite_exists_error'];
						} else {
							$subsite_exists_error = __( 'The specified subsite URL is not available, please try again.', 'rcp-site-creation' );
						}

						rcp_errors()->add( 'subsite_exists_error', $subsite_exists_error, 'register' );
					}
				}
			}

			/**
			 * Fires immediately after core errors have been collected for registration fields.
			 *
			 * @since 1.2
			 *
			 * @param \WP_Post $post     Post object.
			 * @param array    $settings RCP Site Creation settings array.
			 */
			do_action( 'rcp_site_creation_registration_errors', $post, $settings );
		}
	}
}
add_action( 'rcp_before_form_errors', 'rcp_site_creation_registration_errors' );

/**
 * Set pending user meta during registration so we know to create the site later
 *
 * @param array                $post                Posted data.
 * @param int                  $user_id             ID of the user who's registering.
 * @param float                $price               Price of the subscription.
 * @param int                  $payment_id          ID of the pending payment.
 * @param bool|RCP_Customer    $customer            Customer object.
 * @param int                  $membership_id       ID of the pending membership record.
 * @param RCP_Membership|false $previous_membership Previous membership object, or false if none.
 * @param string               $registration_type   Type of registration.
 *
 * @since 1.1.4
 */
function rcp_site_creation_create_pending_site( $post, $user_id, $price, $payment_id = 0, $customer = false, $membership_id = 0, $previous_membership = false, $registration_type = 'new' ) {

	if( isset( $post['rcp_level'] ) && rcp_site_creation_allowed( $post['rcp_level'] ) && isset( $post['rcp_site_creation_url'] ) && $post['rcp_site_creation_url'] !== '' ) {
		$site_args = array(
			'name'          => sanitize_text_field( $post['rcp_site_creation_name'] ),
			'description'   => isset( $post['rcp_site_creation_desc'] ) ? sanitize_text_field( $post['rcp_site_creation_desc'] ) : '',
			'url'           => sanitize_text_field( $_POST['rcp_site_creation_url'] ),
			'scheme'        => isset( $_POST['rcp_site_creation_url_scheme'] ) ? sanitize_text_field( $_POST['rcp_site_creation_url_scheme'] ) : 'http',
			'membership_id' => $membership_id
		);

		rcp_log( sprintf( 'Site Creation: Creating pending site for user #%d.', $user_id ) );

		if ( version_compare( RCP_PLUGIN_VERSION, '3.0', '>=' ) ) {
			rcp_update_membership_meta( $membership_id, 'site_creation_pending_site', $site_args );
		} else {
			update_user_meta( absint( $user_id ), 'rcp_site_creation_pending_site', $site_args );
		}

		/**
		 * Fires immediately after a pending site has been created.
		 *
		 * @since 1.2
		 *
		 * @param \WP_Post $post      Post object.
		 * @param int      $user_id   User ID.
		 * @param array    $site_args Arguments set for the new pending site.
		 */
		do_action( 'rcp_site_creation_create_pending_site', $post, $user_id, $site_args );
	}

}
add_action( 'rcp_form_processing', 'rcp_site_creation_create_pending_site', 10, 8 );

/**
 * Activate the site when the membership is activated.
 *
 * @param int $membership_id ID of the membership.
 * @param RCP_Membership $membership
 *
 * @since 1.2.1
 * @return void
 */
function rcp_site_creation_activate_site( $membership_id, $membership ) {

	$site_meta = rcp_get_membership_meta( $membership_id, 'site_creation_pending_site', true );

	$user_id = $membership->get_customer()->get_user_id();

	if ( empty( $site_meta ) && ! empty( $user_id ) ) {
		// Backwards compat - check old meta key.
		$site_meta = get_user_meta( $user_id, 'rcp_site_creation_pending_site', true );
	}

	if ( empty( $site_meta ) || ! is_array( $site_meta ) || empty( $site_meta['url'] ) ) {
		return;
	}

	rcp_log( sprintf( 'Site Creation: Creating new site for membership #%d.', $membership_id ) );

	$new_domain = rcp_site_creation_get_format( $site_meta['url'] );

	$site_id = rcp_site_creation_create_site_for_membership( $membership, array(
		'domain'      => $new_domain['domain'],
		'path'        => $new_domain['path'],
		'name'        => $site_meta['name'],
		'description' => $site_meta['description'],
		'scheme'      => $site_meta['scheme'],
		'quota'       => rcp_site_creation_get_upload_quota( $membership->get_object_id() ),
		'meta'        => apply_filters( 'rcp_site_creation_status', array( 'public' => 1 ) )
	) );

	/**
	 * Fires after the site has been created.
	 *
	 * @param int|WP_Error   $blog_id    ID of the new blog or WP_Error on failure.
	 * @param RCP_Member     $member     Member object.
	 * @param RCP_Membership $membership Membership object.
	 *
	 * @since 1.2.1
	 */
	do_action( 'rcp_site_creation_after_site_created', $site_id, $membership->get_customer()->get_member(), $membership );

	if ( ! is_wp_error( $site_id ) ) {
		rcp_delete_membership_meta( $membership_id, 'site_creation_pending_site' );
		delete_user_meta( $user_id, 'rcp_site_creation_pending_site' );
	}

}
add_action( 'rcp_membership_post_activate', 'rcp_site_creation_activate_site', 10, 2 );

/**
 * Change membership/site association when a membership is upgraded and then activated.
 *
 * When a new membership is activated, check to see if it was upgraded from a previous membership. If so, the
 * associated site ID should be associated with this new membership instead.
 *
 * @param int $membership_id ID of the membership.
 * @param RCP_Membership $membership
 *
 * @since 1.2.1
 * @return void
 */
function rcp_site_creation_maybe_change_site_membership( $membership_id, $membership ) {

	rcp_log( 'Site Creation: Checking to see if site should be migrated to new membership post-upgrade.' );

	$old_membership_id = $membership->get_upgraded_from();

	if ( empty( $old_membership_id ) ) {
		rcp_log( 'Site Creation: No upgrade detected - exiting.' );

		return;
	}

	$site_id = rcp_site_creation_get_membership_site_id( $old_membership_id );

	if ( empty( $site_id ) ) {
		rcp_log( 'Site Creation: No site detected - exiting.' );

		return;
	}

	rcp_log( sprintf( 'Site Creation: Moving site #%d from old membership #%d to new membership #%d.', $site_id, $old_membership_id, $membership_id ) );

	// Add meta to new membership.
	rcp_add_membership_meta( $membership_id, 'site_creation_site_id', absint( $site_id ) );

	// Delete meta from old membership.
	rcp_delete_membership_meta( $old_membership_id, 'site_creation_site_id' );

	// Update site quota.
	$quota = rcp_site_creation_get_upload_quota( $membership->get_object_id() );

	if ( ! empty( $quota ) ) {
		update_blog_option( $site_id, 'blog_upload_space', absint( $quota ) );
	} else {
		delete_blog_option( $site_id, 'blog_upload_space' );
	}

}
add_action( 'rcp_membership_post_activate', 'rcp_site_creation_maybe_change_site_membership', 20, 2 );

/**
 * Update the customer's site when the membership status changes. If the status is changed to "expired" the site gets
 * deactivated. If the status is changed back to "active" the site gets reactivated.
 *
 * @param string $old_status    Previous membership status.
 * @param string $new_status    New membership status.
 * @param int    $membership_id ID of the membership.
 *
 * @since 1.2.1
 * @return void
 */
function rcp_site_creation_update_site( $old_status, $new_status, $membership_id ) {

	$site_id = rcp_site_creation_get_membership_site_id( $membership_id );

	if ( empty( $site_id ) ) {
		return;
	}

	if ( 'expired' == $new_status ) {

		// Delete site when membership expires.
		rcp_log( sprintf( 'Site Creation: Membership #%d expired, deactivating site #%d.', $membership_id, $site_id ) );

		do_action( 'deactivate_blog', $site_id );
		update_blog_status( $site_id, 'deleted', '1' );

	} elseif ( 'active' == $new_status ) {

		// Re-activate site when membership is re-activated.
		rcp_log( sprintf( 'Site Creation: Membership #%d activated, reactivating site #%d.', $membership_id, $site_id ) );

		update_blog_status( $site_id, 'deleted', '0' );
		do_action( 'activate_blog', $site_id );

	}

}
add_action( 'rcp_transition_membership_status', 'rcp_site_creation_update_site', 10, 3 );

/**
 * Add a link to the member's site dashboard.
 *
 * @param array                $links      Existing membership action links.
 * @param RCP_Membership|false $membership Membership record to show links for.
 *
 * @since 1.2.1
 * @return void
 */
function rcp_site_creation_site_dashboard_link( $links, $membership = false ) {

	if ( ! empty( $membership ) ) {
		$blog_id = rcp_site_creation_get_membership_site_id( $membership->get_id() );
	} else {
		$blog_id = rcp_site_creation_get_user_blog( get_current_user_id() );
	}

	if ( empty( $blog_id ) ) {
		return;
	}

	echo '<p><a href="' . esc_url( get_admin_url( absint( $blog_id ) ) ) . '" target="_blank">' . __( 'Access site dashboard', 'rcp-site-creation' ) . '</a></p>';

}
add_action( 'rcp_subscription_details_action_links', 'rcp_site_creation_site_dashboard_link', 10, 2 );