<?php
/**
 * Edit Member Page
 *
 * @package   RCP\RCP_Site_Creation\Admin\Edit Member
 * @copyright Copyright (c) 2017, Restrict Content Pro
 * @license   GPL2+
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Display site information on the Edit Membership page.
 *
 * @param RCP_Membership $membership Membership object.
 *
 * @return void
 */
function rcp_site_creation_edit_membership( $membership ) {

	$site_id = rcp_site_creation_get_membership_site_id( $membership->get_id() );
	?>
	<tr>
		<th scope="row" class="row-title">
			<label for="rcp-site-creation-blog"><?php _e( 'Site', 'rcp-site-creation' ); ?></label>
		</th>
		<td>
			<?php if ( ! empty( $site_id ) ) :
				$details = get_blog_details( $site_id );
				?>
				<a href="<?php echo esc_url( $details->home ); ?>" target="_blank" title="<?php esc_attr_e( 'Visit site', 'rcp-site-creation' ); ?>"><?php echo esc_html( $details->blogname ); ?></a> |
				<a href="<?php echo esc_url( get_admin_url( $site_id ) ); ?>" target="_blank"><?php _e( 'Dashboard', 'rcp-site-creation' ); ?></a> |
				<a href="<?php echo esc_url( network_admin_url( 'site-info.php?id=' . $details->blog_id ) ); ?>" target="_blank"><?php _e( 'Edit', 'rcp-site-creation' ); ?></a>
			<?php else : ?>
				<input type="number" id="rcp-site-creation-blog" name="rcp_site_creation_blog" value=""/>
				<p class="description"><?php _e( 'Enter a site ID number to associate it with this membership.', 'rcp-site-creation' ); ?></p>
			<?php endif; ?>
		</td>
	</tr>
	<?php

}
add_action( 'rcp_edit_membership_after', 'rcp_site_creation_edit_membership' );

/**
 * Associate the inputted site with the membership.
 *
 * @return void
 */
function rcp_site_creation_add_site_to_membership() {

	if ( ! isset( $_POST['rcp_site_creation_blog'] ) ) {
		return;
	}

	if ( ! current_user_can( 'rcp_manage_members' ) ) {
		wp_die( __( 'You do not have permission to perform this action.', 'rcp-site-creation' ), __( 'Error', 'rcp-site-creation' ), array( 'response' => 403 ) );
	}

	$membership_id = absint( $_POST['membership_id'] );
	$site_id       = absint( $_POST['rcp_site_creation_blog'] );

	if ( empty( $membership_id ) || empty( $site_id ) ) {
		return;
	}

	rcp_log( sprintf( 'Site Creation: Checking to associate site #%d with membership #%d.', $site_id, $membership_id ) );

	// Make sure this site ID isn't already associated with a membership.
	$memberships = rcp_get_memberships( array(
		'fields'     => 'ids',
		'meta_query' => array(
			array(
				'key'   => 'site_creation_site_id',
				'value' => $site_id
			)
		)
	) );

	if ( ! empty( $memberships ) ) {
		rcp_log( sprintf( 'Site Creation: Error - Site #%d is already associated with membership #%d.', $site_id, $memberships[0] ) );

		wp_die( sprintf( __( 'Site #%d is already associated with membership #%d. A site can only be associated with one membership.', 'rcp-site-creation' ), $site_id, reset( $memberships ) ), __( 'Error', 'rcp-site-creation' ), array( 'response' => 400 ) );
	}

	rcp_update_membership_meta( $membership_id, 'site_creation_site_id', $site_id );

	rcp_log( sprintf( 'Site Creation: Successfully associated site #%d with membership #%d.', $site_id, $membership_id ) );

}
add_action( 'rcp_action_edit_membership', 'rcp_site_creation_add_site_to_membership', 9 );