<?php
/**
 * Deprecated Functions
 *
 * @package   ms
 * @copyright Copyright (c) 2019, Ashley Gibson
 * @license   GPL2+
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Create subsite when membership is activated
 *
 * @deprecated 1.2.1 In favour of `rcp_site_creation_activate_site()`
 * @see rcp_site_creation_activate_site()
 *
 * @param string $status     New status being set.
 * @param int    $user_id    ID of the user.
 * @param string $old_status Previous status before the update.
 * @param RCP_Member $member Member object.
 *
 * @since  1.0.0
 * @return void
 */
function rcp_site_creation_set_status( $status, $user_id, $old_status, $member ) {
	if ( version_compare( RCP_PLUGIN_VERSION, '3.0', '>=' ) ) {
		return;
	}

	if( ! in_array( $status, array( 'active', 'free' ) ) ) {
		return;
	}

	$site_meta = get_user_meta( $user_id, 'rcp_site_creation_pending_site', true );

	if ( empty( $site_meta ) || ! is_array( $site_meta ) || empty( $site_meta['url'] ) ) {
		return;
	}

	$new_domain = rcp_site_creation_get_format( $site_meta['url'] );

	$blog_id = rcp_site_creation_create_site_for_member( $member, array(
		'url'         => $site_meta['url'],
		'domain'      => $new_domain['domain'],
		'path'        => $new_domain['path'],
		'name'        => $site_meta['name'],
		'description' => $site_meta['description'],
		'scheme'      => $site_meta['scheme'],
		'meta'        => apply_filters( 'rcp_site_creation_status', array( 'public' => 1 ) )
	) );

	/**
	 * Fires after the site has been created.
	 *
	 * @param int|WP_Error $blog_id ID of the new blog or WP_Error on failure.
	 * @param RCP_Member   $member  Member object.
	 *
	 * @since 1.2.1
	 */
	do_action( 'rcp_site_creation_after_site_created', $blog_id, $member );

	if ( ! is_wp_error( $blog_id ) ) {
		delete_user_meta( $user_id, 'rcp_site_creation_pending_site' );
	}
}
add_action( 'rcp_set_status', 'rcp_site_creation_set_status', 10, 4 );

/**
 * Create a new site on the network for a given member.
 *
 * @deprecated 1.2.1 In favour of `rcp_site_creation_create_site_for_membership()`
 * @see rcp_site_creation_create_site_for_member()
 *
 * @param RCP_Member|int $member Member object or ID number.
 * @param array          $args   Site arguments.
 *
 * @since 1.2.1
 * @return int|WP_Error ID of the new site if created, or WP_Error object on failure.
 */
function rcp_site_creation_create_site_for_member( $member, $args = array() ) {

	$settings = get_option( 'rcp_site_creation_settings' );

	if ( ! is_object( $member ) ) {
		$member = new RCP_Member( $member );
	}

	if ( empty( $member->ID ) ) {
		return new WP_Error( 'invalid_member', __( 'Please supply a valid member object or ID.', 'rcp-site-creation' ) );
	}

	$default_args = array(
		'url'         => '', // Just used for backwards compat.
		'domain'      => '',
		'path'        => '',
		'name'        => '',
		'description' => '',
		'scheme'      => 'http',
		'quota'       => rcp_site_creation_get_upload_quota( $member->get_subscription_id() ),
		'meta'        => array(
			'public' => 1 // Site status
		)
	);

	$args = wp_parse_args( $args, $default_args );

	// URL is required.
	if ( empty( $args['domain'] ) || empty( $args['path'] ) ) {
		return new WP_Error( 'empty_domain_path', __( 'The site domain and path are required.', 'rcp-site-creation' ) );
	}

	$meta = $args['meta'];

	if ( ! empty( $args['description'] ) ) {
		$meta['blogdescription'] = sanitize_text_field( $args['description'] );
	}

	if ( ! empty( $args['quota'] ) ) {
		$meta['blog_upload_space'] = absint( $args['quota'] );
	}

	if ( ! empty( $settings['domain_mapping'] ) ) {
		// We need to overwrite the site/home URLs manually in order to change the scheme.
		$url = $args['scheme'] . '://' . $args['domain'];
		$meta['siteurl'] = sanitize_text_field( $url );
		$meta['home']    = sanitize_text_field( $url );
	}

	/**
	 * Filters the meta array used during site creation.
	 *
	 * @since 1.0.0
	 *
	 * @param array $meta Site meta array.
	 * @param array $args Site arguments.
	 */
	$meta = apply_filters( 'rcp_site_creation_meta', $meta, $args );

	$blog_id = wpmu_create_blog( $args['domain'], $args['path'], $args['name'], $member->ID, $meta );

	if ( is_wp_error( $blog_id ) ) {
		return $blog_id;
	}

	// Set theme.
	if ( isset( $settings['default_theme'] ) && ! empty( $settings['default_theme'] ) ) {
		switch_to_blog( $blog_id );
		switch_theme( $settings['default_theme'] );
		restore_current_blog();
	}

	/**
	 * Fires immediately after a site has been created and the default theme set,
	 * but before the user meta flag is deleted.
	 *
	 * @since 1.2
	 *
	 * @param array $site_meta Array of meta for the newly-added site.
	 * @param int   $blog_id   ID of the new site.
	 * @param int   $user_id   User ID for the admin associated with the new site.
	 */
	do_action( 'rcp_site_creation_site_created', $args, $blog_id, $member->ID );

	/**
	 * Add meta to this member designating that this is their Site Creation site.
	 */
	update_user_meta( $member->ID, 'rcp_site_creation_blog_id', $blog_id );

	return $blog_id;

}

/**
 * Get the registered blog for a user
 *
 * @deprecated 1.2.1 In favour of `rcp_site_creation_get_membership_site_id()`
 * @see rcp_site_creation_get_membership_site_id()
 *
 * @since       1.0.0
 * @param       int $user_id The ID of the user to lookup
 * @return      int|false $blog_id The ID of the users' blog
 */
function rcp_site_creation_get_user_blog( $user_id ) {

	$blog_id = get_user_meta( $user_id, 'rcp_site_creation_blog_id', true );

	if ( version_compare( RCP_PLUGIN_VERSION, '3.0', '>=' ) ) {
		/**
		 * RCP 3.0+
		 */

		if ( ! empty( $blog_id ) ) {
			// Migrate the user meta to membership meta.

			// Guess the membership ID from the customer.
			$customer = rcp_get_customer_by_user_id( $user_id );

			if ( ! empty( $customer ) ) {
				$membership = rcp_get_customer_single_membership( $customer->get_id() );

				if ( ! empty( $membership ) ) {
					rcp_add_membership_meta( $membership->get_id(), 'site_creation_site_id', absint( $blog_id ) );
					delete_user_meta( $user_id, 'rcp_site_creation_blog_id' );
				}
			}
		} else {
			// Get the site ID from membership meta.
			$customer = rcp_get_customer_by_user_id( $user_id );

			if ( ! empty( $customer ) ) {
				$membership = rcp_get_customer_single_membership( $customer->get_id() );

				if ( ! empty( $membership ) ) {
					$blog_id = rcp_site_creation_get_membership_site_id( $membership->get_id() );
				}
			}
		}
	}

	if ( empty( $blog_id ) ) {
		return false;
	}

	$details = get_blog_details( $blog_id );

	return ! empty( $details ) ? $blog_id : false;
}

/**
 * Update an existing subsite when the member's status is updated
 *
 * @deprecated 1.2.1 In favour of `rcp_site_creation_update_site()`
 * @see rcp_site_creation_update_site()
 *
 * @param string $status     New status being set.
 * @param int    $user_id    ID of the user.
 * @param string $old_status Previous status before the update.
 * @param RCP_Member $member Member object.
 *
 * @since 1.1.4
 * @return void
 */
function rcp_site_creation_update_blog( $status, $user_id, $old_status, $member ) {

	if ( version_compare( RCP_PLUGIN_VERSION, '3.0', '>-' ) ) {
		return;
	}

	$blog_id = rcp_site_creation_get_user_blog( $user_id );

	if ( empty( $blog_id ) ) {
		return;
	}

	if( $status == 'expired' ) {

		// Delete blog when subscription expires.
		do_action( 'deactivate_blog', $blog_id );
		update_blog_status( $blog_id, 'deleted', '1' );

	} elseif( $status == 'active' ) {

		// Re-activate blog when subscription is re-activated.
		update_blog_status( $blog_id, 'deleted', '0' );
		do_action( 'activate_blog', $blog_id );

		// Update quota on subscription upgrade.
		$member = new RCP_Member( $user_id );

		// Change upload space allowance on upgrade.
		if ( $member->just_upgraded() ) {
			$quota = rcp_site_creation_get_upload_quota( $member->get_subscription_id() );

			if ( ! empty( $quota ) ) {
				update_blog_option( $blog_id, 'blog_upload_space', absint( $quota ) );
			}
		}

	}

}
add_action( 'rcp_set_status', 'rcp_site_creation_update_blog', 10, 4 );

/**
 * Display site information on the Edit Member page
 *
 * @deprecated 1.2.1 In favour of `rcp_site_creation_edit_membership()`
 * @see rcp_site_creation_edit_membership()
 *
 * @param int $user_id ID of the member being edited.
 *
 * @since 1.1.4
 * @return void
 */
function rcp_site_creation_edit_member( $user_id ) {

	if ( version_compare( RCP_PLUGIN_VERSION, '3.0', '>=' ) ) {
		return;
	}

	$blog_id = rcp_site_creation_get_user_blog( $user_id );
	?>
	<tr valign="top">
		<th scope="row" valign="top">
			<label for="rcp-site-creation-blog"><?php _e( 'Site', 'rcp-site-creation' ); ?></label>
		</th>
		<td>
			<?php if ( ! empty( $blog_id ) ) :
				$details = get_blog_details( $blog_id );
				?>
				<a href="<?php echo esc_url( $details->home ); ?>" target="_blank" title="<?php esc_attr_e( 'Visit site', 'rcp-site-creation' ); ?>"><?php echo esc_html( $details->blogname ); ?></a> |
				<a href="<?php echo esc_url( get_admin_url( $blog_id ) ); ?>" target="_blank"><?php _e( 'Dashboard', 'rcp-site-creation' ); ?></a> |
				<a href="<?php echo esc_url( network_admin_url( 'site-info.php?id=' . $details->blog_id ) ); ?>" target="_blank"><?php _e( 'Edit', 'rcp-site-creation' ); ?></a>
			<?php else : ?>
				<input type="number" id="rcp-site-creation-blog" name="rcp_site_creation_blog" value=""/>
				<p class="description"><?php _e( 'Enter a site ID number to associate it with this member.', 'rcp-site-creation' ); ?></p>
			<?php endif; ?>
		</td>
	</tr>
	<?php

}

add_action( 'rcp_edit_member_after', 'rcp_site_creation_edit_member' );

/**
 * Associate a member with an existing site
 *
 * @deprecated 1.2.1 In favour of `rcp_site_creation_add_site_to_membership()`
 * @see rcp_site_creation_add_site_to_membership()
 *
 * @param int $user_id ID of the member being edited.
 *
 * @since 1.1.4
 * @return void
 */
function rcp_site_creation_add_blog_to_member( $user_id ) {

	if ( version_compare( RCP_PLUGIN_VERSION, '3.0', '>=' ) ) {
		return;
	}

	if ( ! isset( $_POST['rcp_site_creation_blog'] ) ) {
		return;
	}

	if ( ! current_user_can( 'rcp_manage_members' ) ) {
		wp_die( __( 'You do not have permission to perform this action.', 'rcp-site-creation' ), __( 'Error', 'rcp-site-creation' ), array( 'response' => 403 ) );
	}

	$blog_id = absint( $_POST['rcp_site_creation_blog'] );

	if ( empty( $blog_id ) ) {
		return;
	}

	// Make sure this blog ID isn't already associated with a member.
	$members = get_users( array(
		'meta_key'   => 'rcp_site_creation_blog_id',
		'meta_value' => $blog_id,
		'fields'     => 'ids'
	) );

	if ( ! empty( $members ) ) {
		wp_die( sprintf( __( 'Blog #%d is already associated with user #%d. A blog can only be associated with one member.', 'rcp-site-creation' ), $blog_id, reset( $members ) ), __( 'Error', 'rcp-site-creation' ), array( 'response' => 400 ) );
	}

	update_user_meta( $user_id, 'rcp_site_creation_blog_id', $blog_id );

}

add_action( 'rcp_edit_member', 'rcp_site_creation_add_blog_to_member' );