<?php
/**
 * Filters
 *
 * @package     RCP\Site_Creation\Filters
 * @since       1.0.0
 */


// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Override rcp_get_return_url
 *
 * @since       1.0.0
 * @param       string $redirect_url The current redirect URL
 * @param       $user_id int The user ID we have just registered
 * @return      string $redirect_url The updated redirect URL
 */
function rcp_site_creation_return_url( $redirect_url, $user_id ) {
	$settings = get_option( 'rcp_site_creation_settings' );

	if ( ! isset( $settings['redirect_page'] ) ) {
		return $redirect_url;
	}

	if ( ! in_array( $settings['redirect_page'], array( 'subsite', 'inherit' ) ) ) {
		$redirect_url = get_permalink( $settings['redirect_page'] );

		return $redirect_url;
	}

	if ( version_compare( RCP_PLUGIN_VERSION, '3.0', '>=' ) ) {

		/**
		 * RCP 3.0+
		 */

		$customer = rcp_get_customer_by_user_id( $user_id );

		if ( ! empty( $customer ) ) {
			// Get their most recent membership.
			$memberships = $customer->get_memberships( array(
				'orderby' => 'created_date',
				'order'   => 'DESC'
			) );

			if ( ! empty( $memberships[0] ) ) {
				/**
				 * @var RCP_Membership $membership
				 */
				$membership = $memberships[0];

				if ( ! rcp_site_creation_allowed( $membership->get_object_id() ) ) {
					return $redirect_url;
				}

				$site_id = rcp_get_membership_meta( $membership->get_id(), 'site_creation_pending_site', true );

				if ( ! empty( $site_id ) ) {
					$redirect_url = get_blogaddress_by_id( $site_id );
				}
			}
		}

	} else {
		/**
		 * RCP 2.9 and below
		 */

		$subscription = rcp_get_subscription_id( $user_id );

		if ( rcp_site_creation_allowed( $subscription ) ) {
			if ( $settings['redirect_page'] == 'subsite' ) {
				$blog_id      = rcp_site_creation_get_user_blog( $user_id );
				$redirect_url = get_blogaddress_by_id( $blog_id );
			}
		}
	}

	return $redirect_url;
}
add_filter( 'rcp_return_url', 'rcp_site_creation_return_url', 10, 2 );
