<?php
/**
 * Shortcodes
 *
 * @package   RCP\Site_Creation\Shortcodes
 * @copyright Copyright (c) 2018, Restrict Content Pro team
 * @license   GPL2+
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Shows a link to the current user's site (front-end or admin dashboard).
 *
 * @param array $atts Shortcode attributes.
 * @param null  $content
 *
 * @since 1.2.1
 * @return string
 */
function rcp_site_creation_site_shortcode( $atts, $content = null ) {

	$atts = shortcode_atts( array(
		'page'            => 'front', // "front" for front-end, "admin" for admin area.
		'no_site_message' => '', // Message to show to users who do not have a site.
	), $atts, 'site_creation_url' );

	$site_id = rcp_site_creation_get_user_blog( get_current_user_id() );

	if ( empty( $site_id ) ) {
		return $atts['no_site_message'];
	}

	if ( 'admin' == $atts['page'] ) {
		$url = get_admin_url( absint( $site_id ) );
	} else {
		$details = get_blog_details( absint( $site_id ) );
		$url     = $details->home;
	}

	return '<a href="' . esc_url( $url ) . '">' . esc_html( $url ) . '</a>';

}

add_shortcode( 'site_creation_url', 'rcp_site_creation_site_shortcode' );