<?php
/**
 * Plugin Name:     Restrict Content Pro - Site Creation
 * Plugin URI:      https://restrictcontentpro.com/downloads/site-creation/
 * Description:     Enables a WordPress Multisite subsite creation option for RCP subscriptions
 * Version:         1.3.1
 * Author:          Sandhills Development, LLC
 * Author URI:      https://sandhillsdev.com
 * Text Domain:     rcp-site-creation
 * iThemes Package: rcp-site-creation
 *
 * @package         RCP\Site_Creation
 * @author          Daniel J Griffiths <dgriffiths@section214.com>
 * @copyright       Copyright (c) 2016, Daniel J Griffiths
 */


// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) {
	exit;
}


if( ! class_exists( 'RCP_Site_Creation' ) ) {


	/**
	 * Main RCP_Site_Creation class
	 *
	 * @since       1.0.0
	 */
	class RCP_Site_Creation {


		/**
		 * @var         RCP_Site_Creation $instance The one true RCP_Site_Creation
		 * @since       1.0.0
		 */
		private static $instance;


		/**
		 * Get active instance
		 *
		 * @access      public
		 * @since       1.0.0
		 * @return      object self::$instance The one true RCP_Site_Creation
		 */
		public static function instance() {
			if( ! self::$instance ) {
				self::$instance = new RCP_Site_Creation();
				self::$instance->setup_constants();
				self::$instance->includes();
				self::$instance->load_textdomain();
				self::$instance->hooks();
			}

			return self::$instance;
		}


		/**
		 * Setup plugin constants
		 *
		 * @access      private
		 * @since       1.0.0
		 * @return      void
		 */
		public function setup_constants() {
			// Plugin version
			define( 'RCP_SITE_CREATION_VER', '1.3.1' );

			// Plugin path
			define( 'RCP_SITE_CREATION_DIR', plugin_dir_path( __FILE__ ) );

			// Plugin URL
			define( 'RCP_SITE_CREATION_URL', plugin_dir_url( __FILE__ ) );
		}


		/**
		 * Include necessary files
		 *
		 * @access      private
		 * @since       1.0.0
		 * @return      void
		 */
		private function includes() {
			if( is_multisite() ) {
				require_once RCP_SITE_CREATION_DIR . 'includes/functions.php';
				require_once RCP_SITE_CREATION_DIR . 'includes/ajax-functions.php';
				require_once RCP_SITE_CREATION_DIR . 'includes/scripts.php';
				require_once RCP_SITE_CREATION_DIR . 'includes/filters.php';
				require_once RCP_SITE_CREATION_DIR . 'includes/actions.php';
				require_once RCP_SITE_CREATION_DIR . 'includes/shortcodes.php';
				require_once RCP_SITE_CREATION_DIR . 'includes/deprecated.php';

				if( is_admin() ) {
					require_once RCP_SITE_CREATION_DIR . 'includes/admin/edit-member.php';
					require_once RCP_SITE_CREATION_DIR . 'includes/admin/settings/register.php';
				}
			}
		}


		/**
		 * Run action and filter hooks
		 *
		 * @access      private
		 * @since       1.0.0
		 * @return      void
		 */
		private function hooks() {

			if( ! is_multisite() ) {
				add_action( 'admin_notices', array( $this, 'admin_notice' ) );
			}

			if( class_exists( 'RCP_Add_On_Updater' ) ) {
				$updater = new RCP_Add_On_Updater( 18344, __FILE__, RCP_SITE_CREATION_VER );
			}

		}


		/**
		 * Internationalization
		 *
		 * @access      public
		 * @since       1.0.0
		 * @return      void
		 */
		public static function load_textdomain() {
			// Set filter for language directory
			$lang_dir = dirname( plugin_basename( __FILE__ ) ) . '/languages/';
			$lang_dir = apply_filters( 'rcp_site_creation_languages_directory', $lang_dir );

			// Traditional WordPress plugin locale filter
			$locale = apply_filters( 'plugin_locale', get_locale(), 'rcp-site-creation' );
			$mofile = sprintf( '%1$s-%2$s.mo', 'rcp-site-creation', $locale );

			// Setup paths to current locale file
			$mofile_local  = $lang_dir . $mofile;
			$mofile_global = WP_LANG_DIR . '/rcp-site-creation/' . $mofile;

			if( file_exists( $mofile_global ) ) {
				// Look in global /wp-content/languages/rcp-site-creation/ folder
				load_textdomain( 'rcp-site-creation', $mofile_global );
			} elseif( file_exists( $mofile_local ) ) {
				// Look in local /wp-content/plugins/rcp-site-creation/languages/ folder
				load_textdomain( 'rcp-site-creation', $mofile_local );
			} else {
				// Load the default language files
				load_plugin_textdomain( 'rcp-site-creation', false, $lang_dir );
			}
		}


		/**
		 * Display admin notices
		 *
		 * @since       1.0.0
		 * @return      void
		 */
		public function admin_notice() {
				echo '<div class="error info"><p>' . sprintf( __( 'RCP Site Creation requires a WordPress Multisite installation! Please see %s for more information.', 'rcp-site-creation' ), '<a href="http://codex.wordpress.org/Create_A_Network" target="_blank">' . __( 'this article', 'rcp-site-creation' ) . '</a>' ) . '</p></div>';
		}
	}
}


/**
 * The main function responsible for returning the one true RCP_Site_Creation
 * instance to functions everywhere
 *
 * @since       1.0.0
 * @return      RCP_Site_Creation The one true RCP_Site_Creation
 */
function rcp_site_creation() {
	return RCP_Site_Creation::instance();
}
add_action( 'plugins_loaded', 'rcp_site_creation' );


if ( ! function_exists( 'ithemes_repository_name_updater_register' ) ) {
	function ithemes_repository_name_updater_register( $updater ) {
		$updater->register( 'rcp-site-creation', __FILE__ );
	}
	add_action( 'ithemes_updater_register', 'ithemes_repository_name_updater_register' );

	require( __DIR__ . '/lib/updater/load.php' );
}
