<?php
/**
 * Filters
 *
 * @package     RCP\Timelock\Filters
 * @since       1.0.0
 */


// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Override RCP can_access
 *
 * @since       1.0.0
 * @param       bool $can_access The current access condition
 * @param       int $user_id The ID of the current user
 * @param       int $post_id The ID of the current post
 * @param       object $member The RCP Member object
 * @return      bool $can_access True if whitelisted, false otherwise
 */
function rcp_timelock_member_can_access( $can_access, $user_id = 0, $post_id = 0, $member = false ) {
	if( ! $can_access ) {
		$timelock = get_post_meta( $post_id, 'rcp_timelock', true );

		// If the post isn't timelocked, check the terms.
		if ( empty( $timelock ) ) {
			$term_restricted_post_ids = rcp_get_post_ids_assigned_to_restricted_terms();
			$post_terms               = (array) rcp_get_connected_term_ids( $post_id );

			if ( in_array( $post_id, $term_restricted_post_ids ) && ! empty( $post_terms ) ) {
				foreach ( $post_terms as $post_term_id ) {
					$term_timelock_date = rcp_timelock_get_term_lock( $post_term_id );

					if ( empty( $term_timelock_date ) ) {
						continue;
					}

					$timelock = $term_timelock_date;
					break;
				}
			}
		}

		if( $timelock ) {
			$current_time = current_time( 'm/d/Y H:i' );

			if( strtotime( $current_time ) < strtotime( esc_attr( $timelock ) ) ) {
				$can_access = true;
			}
		}
	}

	return $can_access;
}
add_filter( 'rcp_member_can_access', 'rcp_timelock_member_can_access', 10, 4 );


/**
 * Override restrict shortcode
 *
 * @since       1.0.1
 * @param       bool $has_access The current access condition
 * @param       int $user_id The ID of the current user
 * @param       array $atts Arguements passed to the shortcode
 * @return      bool $has_access True if whitelisted, false otherwise
 */
function rcp_timelock_shortcode_can_access( $has_access, $user_id = 0, $atts ) {
	if( ! $has_access ) {
		$timelock = get_post_meta( get_the_ID(), 'rcp_timelock', true );

		if( $timelock ) {
			$current_time = current_time( 'm/d/Y H:i' );

			if( strtotime( $current_time ) < strtotime( esc_attr( $timelock ) ) ) {
				$has_access = true;
			}
		}
	}

	return $has_access;
}
add_filter( 'rcp_restrict_shortcode_has_access', 'rcp_timelock_shortcode_can_access', 10, 3 );
