<?php
/**
 * Helper Functions
 *
 * @package   RCP\Timelock\Functions
 * @copyright Copyright (c) 2017, Restrict Content Pro
 * @license   GPL2+
 * @since     1.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Get timelock for the provided term ID. This is the date the content will become restricted.
 *
 * @param int $term_id ID of the term to get the value for.
 *
 * @since 1.1
 * @return string|false
 */
function rcp_timelock_get_term_lock( $term_id ) {

	$timelock = false;

	if ( function_exists( 'get_term_meta' ) ) {
		$timelock = get_term_meta( $term_id, 'rcp_timelock', true );
	}

	return $timelock;

}

/**
 * Get past timelock for the provided term ID. This value returns the date the content beceame restricted.
 * It's used when the date has already passed.
 *
 * @param int $term_id ID of the term to get the value for.
 *
 * @since 1.1
 * @return string|false
 */
function rcp_timelock_get_past_term_lock( $term_id ) {

	$timelock_was = false;

	if ( function_exists( 'get_term_meta' ) ) {
		$timelock_was = get_term_meta( $term_id, 'rcp_timelock_was', true );
	}

	return $timelock_was;

}