<?php

RCPBP_Setup::get_instance();

class RCPBP_Setup {

	/**
	 * @var
	 */
	protected static $_instance;

	/**
	 * Only make one instance of the RCPBP_Setup
	 *
	 * @return RCPBP_Setup
	 */
	public static function get_instance() {
		if ( ! self::$_instance instanceof RCPBP_Setup ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	/**
	 * Add Hooks and Actions
	 */
	protected function __construct() {
		add_action( 'plugins_loaded', array( $this, 'maybe_setup' ), - 9999 );

		add_action( 'updated_option', array( $this, 'activate_license' ), 100 );
		add_action( 'updated_option', array( $this, 'deactivate_license' ), 100 );
		add_action( 'admin_init', array( $this, 'register_settings' ), 50 );
		add_action( 'admin_menu', array( $this, 'admin_menu' ), 50 );
		add_action( 'admin_notices', array( $this, 'license_admin_notice' ) );
		add_action( 'admin_notices', array( $this, 'rcp_version_notice' ) );

		add_action( 'admin_enqueue_scripts', array( $this, 'admin_styles' ) );
	}

	public function maybe_setup() {
		if ( ! $this->check_required_plugins() ) {
			return;
		}

		$this->includes();
	}

	protected function includes() {
		include_once( RCPBP_PATH . '/includes/components.php' );
		include_once( RCPBP_PATH . '/includes/member-types.php' );
		include_once( RCPBP_PATH . '/includes/profile.php' );
		include_once( RCPBP_PATH . '/includes/restricted-content.php' );
		include_once( RCPBP_PATH . '/includes/groups.php' );
		include_once( RCPBP_PATH . '/includes/admin/terms.php' );
	}

	/**
	 * Initialize admin scripts and styles
	 *
	 * @param $hook
	 */
	public function admin_styles( $hook ) {
		global $rcp_members_page, $rcp_subscriptions_page, $rcp_discounts_page, $rcp_payments_page, $rcp_reports_page, $rcp_settings_page, $rcp_export_page, $rcp_logs_page, $rcp_help_page, $rcp_tools_page, $rcp_add_ons_page;
		$pages = array(
			$rcp_members_page,
			$rcp_subscriptions_page,
			$rcp_discounts_page,
			$rcp_payments_page,
			$rcp_reports_page,
			$rcp_settings_page,
			$rcp_export_page,
			$rcp_logs_page,
			$rcp_help_page,
			$rcp_tools_page,
			$rcp_add_ons_page,
			'post.php',
			'edit.php',
			'post-new.php',
			'term.php',
			'edit-tags.php',
			'restrict_page_rcpbp-settings'
		);

		wp_register_style( 'rcpbp-admin-css', RCPBP_URL . 'assets/css/admin-styles.css', array(), RCPBP_VERSION );
		wp_enqueue_script( 'rcpbp-admin-js', RCPBP_URL . 'assets/js/admin.min.js', array( 'jquery' ), RCPBP_VERSION );

		if ( in_array( $hook, $pages ) ) {
			wp_enqueue_style( 'rcpbp-admin-css' );
			wp_enqueue_script( 'rcpbp-admin-js' );
		}
	}

	/**
	 * Make sure RCP and BuddyPress are active
	 * @return bool
	 */
	protected function check_required_plugins() {

		if ( ! function_exists( 'is_plugin_active' ) ) {
			require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		}

		if ( is_plugin_active( 'restrict-content-pro/restrict-content-pro.php' ) && is_plugin_active( 'buddypress/bp-loader.php' ) ) {
			return true;
		}

		add_action( 'admin_notices', array( $this, 'required_plugins' ) );

		return false;
	}

	/**
	 * Required Plugins notice
	 */
	public function required_plugins() {
		printf( '<div class="error"><p>%s</p></div>', __( 'Restrict Content Pro and BuddyPress are both required for the Restrict Content Pro BuddyPress add-on to function.', 'rcpbp' ) );
	}

	/**
	 * Register the RCP BP settings
	 *
	 * @access      public
	 * @return      void
	 * @since       1.0.0
	 */
	public function register_settings() {
		register_setting( 'rcpbp_settings_group', 'rcpbp_license_key', array( $this, 'sanitize_license' ) );
		register_setting( 'rcpbp_restrict_group', 'rcpbp_vis_rd_page', array( $this, 'sanitize_vis_rd_page' ) );
		register_setting( 'rcpbp_restrict_group', 'rcpbp_vis_rd_toggle', array( $this, 'sanitize_vis_rd_toggle' ) );
		register_setting( 'rcpbp_restrict_group', 'rcpbp_memtype_toggle', array( $this, 'sanitize_memtype_toggle' ) );
		register_setting( 'rcpbp_restrict_group', 'rcpbp_public_components', [ $this, 'sanitize_components' ] );
		register_setting( 'rcpbp_restrict_group', 'rcpbp_components_toggle', [ $this, 'sanitize_components_toggle' ] );

		// Add visibility settings section
		add_settings_section(
			'rcpbp_bp_restrict_section',
			__( 'Restriction Settings', 'rcpbp' ),
			null,
			RCPBP_PLUGIN_LICENSE_PAGE
		);

		// Add visibility settings section
		add_settings_section(
			'rcpbp_memtype_section',
			__( 'Member Types', 'rcpbp' ),
			null,
			RCPBP_PLUGIN_LICENSE_PAGE
		);

		// Add checkbox to enable component restriction
		add_settings_field(
			'rcpbp_components_toggle',
			'Enable Component Restriction',
			[ $this, 'rcpbp_components_toggle_callback' ],
			RCPBP_PLUGIN_LICENSE_PAGE,
			'rcpbp_bp_restrict_section'
		);

		// Add public component checkboxes
		add_settings_field(
			'rcpbp_public_components',
			null,
			[ 'RCPBP_Components', 'meta_fields' ],
			RCPBP_PLUGIN_LICENSE_PAGE,
			'rcpbp_bp_restrict_section',
			[ 'class' => 'rcpbp-public-components' ]
		);

		// Add checkbox to enable page redirect
		add_settings_field(
			'rcpbp_bp_vis_rd_toggle',
			'Enable redirection',
			array( $this, 'rcpbp_bp_vis_toggle_callback' ),
			RCPBP_PLUGIN_LICENSE_PAGE,
			'rcpbp_bp_restrict_section'
		);

		// Add field to select redirect pages
		add_settings_field(
			'rcpbp_bp_vis_rd_page',
			'Redirect to page',
			array( $this, 'rcpbp_bp_vis_rd_page_callback' ),
			RCPBP_PLUGIN_LICENSE_PAGE,
			'rcpbp_bp_restrict_section',
			[ 'class' => 'rcpbp_bp_vis_rd_page' ]
		);

		// toggle member types
		add_settings_field(
			'rcpbp_memtype_toggle',
			'Remove member types when membership is not active',
			array( $this, 'rcpbp_memtype_toggle_callback' ),
			RCPBP_PLUGIN_LICENSE_PAGE,
			'rcpbp_memtype_section'
		);
	}

	/**
	 * Add the BuddyPress menu item
	 *
	 * @access      public
	 * @return      void
	 * @since       1.0.0
	 */
	public function admin_menu() {
		add_submenu_page( 'rcp-members', __( 'BuddyPress Settings', 'rcpbp' ), __( 'BuddyPress', 'rcpbp' ), 'manage_options', RCPBP_PLUGIN_LICENSE_PAGE, array(
			$this,
			'settings_page'
		) );
	}

	public function settings_page() {
		$license = get_option( 'rcpbp_license_key', '' );
		$status  = get_option( 'rcpbp_license_status', '' );

		if ( isset( $_REQUEST['updated'] ) && $_REQUEST['updated'] !== false ) : ?>
            <div class="updated fade"><p><strong><?php _e( 'Options saved', 'rcpbp' ); ?></strong></p></div>
		<?php endif; ?>

        <div class="rcpbp-wrap">

            <h2 class="rcpbp-settings-title"><?php echo esc_html( get_admin_page_title() ); ?></h2>
            <hr>

			<?php $active_tab = isset( $_GET['tab'] ) ? $_GET['tab'] : 'general_options'; ?>

            <h2 class="nav-tab-wrapper">
                <a href="?page=rcpbp-settings&tab=general_options"
                   class="nav-tab <?php echo $active_tab == 'general_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'General', 'rcbp' ); ?></a>
                <a href="?page=rcpbp-settings&tab=restrict_options"
                   class="nav-tab <?php echo $active_tab == 'restrict_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Settings', 'rcbp' ); ?></a>
            </h2>

            <form method="post" action="options.php" class="rcp_options_form">
				<?php if ( $active_tab == 'general_options' ) {
					settings_fields( 'rcpbp_settings_group' ); ?>

                    <table class="form-table">
                        <tr>
                            <th>
                                <label for="rcpbp_license_key"><?php _e( 'License Key', 'rcpbp' ); ?></label>
                            </th>
                            <td>
                                <p><input class="regular-text" type="text" id="rcpbp_license_key"
                                          name="rcpbp_license_key" value="<?php echo esc_attr( $license ); ?>"/>
									<?php if ( $status == 'valid' ) : ?>
										<?php wp_nonce_field( 'rcpbp_deactivate_license', 'rcpbp_deactivate_license' ); ?>
										<?php submit_button( 'Deactivate License', 'secondary', 'rcpbp_license_deactivate', false ); ?>
                                        <span style="color:green">&nbsp;&nbsp;<?php _e( 'active', 'rcpbp' ); ?></span>
									<?php elseif ( $license ) : ?>
										<?php submit_button( 'Activate License', 'secondary', 'rcpbp_license_activate', false ); ?>
									<?php endif; ?></p>

                                <p class="description"><?php printf( __( 'Enter your Restrict Content Pro - BuddyPress license key. This is required for automatic updates and <a href="%s">support</a>.', 'rcpbp' ), 'https://skillfulplugins.com/contact/' ); ?></p>
                            </td>
                        </tr>

                    </table>

					<?php
					settings_fields( 'rcpbp_settings_group' );
					wp_nonce_field( 'rcpbp_nonce', 'rcpbp_nonce' );
				} elseif ( $active_tab == 'restrict_options' ) {
					// restrict options page fields
					settings_fields( 'rcpbp_restrict_group' );
					do_settings_sections( RCPBP_PLUGIN_LICENSE_PAGE );
				}
				submit_button( 'Save Options' );
				?>
            </form>
        </div>

		<?php
	}

	// Sanitize functions 
	public function sanitize_license( $new ) {
		$old = get_option( 'rcpbp_license_key' );
		if ( $old && $old != $new ) {
			delete_option( 'rcpbp_license_key' ); // new license has been entered, so must reactivate
		}

		return $new;
	}

	// sanitize checkbox input for visibility toggle
	public function sanitize_vis_rd_toggle() {
		if ( isset( $_POST['rcpbp_bp_vis_rd_toggle'] ) ) {
			return sanitize_key( $_POST['rcpbp_bp_vis_rd_toggle'] );
		}
	}

	// sanitize checkbox input for visibility toggle
	public function sanitize_components_toggle() {
		if ( isset( $_POST['rcpbp_components_toggle'] ) ) {
			return sanitize_key( $_POST['rcpbp_components_toggle'] );
		}
	}

	// sanitize list of components
	public function sanitize_components() {

		$components = isset( $_POST['rcpbp-components'] ) ? (array) $_POST['rcpbp-components'] : 0;

		if ( empty( $components ) ) {
			return [];
		}

		return array_map( 'esc_attr', $components );
	}

	// sanitize page ID to make ensure stored value is a number
	public function sanitize_vis_rd_page() {
		if ( isset( $_POST['rcpbp_bp_vis_rd_page'] ) ) {
			return absint( $_POST['rcpbp_bp_vis_rd_page'] );
		}
	}

	public function sanitize_memtype_toggle() {
		if ( isset( $_POST['rcpbp_memtype_toggle'] ) ) {
			return absint( $_POST['rcpbp_memtype_toggle'] );
		}
	}

	public function activate_license() {

		// listen for our activate button to be clicked
		if ( ! isset( $_POST['rcpbp_license_activate'], $_POST['rcpbp_nonce'] ) ) {
			return;
		}

		// run a quick security check
		if ( ! check_admin_referer( 'rcpbp_nonce', 'rcpbp_nonce' ) ) {
			return;
		} // get out if we didn't click the Activate button

		// retrieve the license from the database
		$license = trim( get_option( 'rcpbp_license_key' ) );

		// data to send in our API request
		$api_params = array(
			'edd_action' => 'activate_license',
			'license'    => $license,
			'item_name'  => urlencode( RCPBP_ITEM_NAME ), // the name of our product in EDD
			'url'        => home_url()
		);

		// Call the custom API.
		$response = wp_remote_post( RCPBP_STORE_URL, array(
			'timeout'   => 15,
			'sslverify' => false,
			'body'      => $api_params
		) );

		if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {

			if ( is_wp_error( $response ) ) {
				$message = $response->get_error_message();
			} else {
				$message = __( 'An error occurred, please try again.' );
			}

		} else {

			// decode the license data
			$license_data = json_decode( wp_remote_retrieve_body( $response ) );

			if ( false === $license_data->success ) {

				switch ( $license_data->error ) {

					case 'expired' :

						$message = sprintf(
							__( 'Your license key expired on %s.' ),
							date_i18n( get_option( 'date_format' ), strtotime( $license_data->expires, current_time( 'timestamp' ) ) )
						);
						break;

					case 'revoked' :

						$message = __( 'Your license key has been disabled.' );
						break;

					case 'missing' :

						$message = __( 'Invalid license.' );
						break;

					case 'invalid' :
					case 'site_inactive' :

						$message = __( 'Your license is not active for this URL.' );
						break;

					case 'item_name_mismatch' :

						$message = sprintf( __( 'This appears to be an invalid license key for %s.' ), RCPBP_ITEM_NAME );
						break;

					case 'no_activations_left':

						$message = __( 'Your license key has reached its activation limit.' );
						break;

					default :

						$message = __( 'An error occurred, please try again.' );
						break;
				}

			}
		}

		delete_transient( 'rcpbp_license_check' );

		// Check if anything passed on a message constituting a failure
		if ( ! empty( $message ) ) {
			$base_url = admin_url( 'admin.php?page=' . RCPBP_PLUGIN_LICENSE_PAGE );
			$redirect = add_query_arg( array(
				'sl_activation' => 'false',
				'message'       => urlencode( $message )
			), $base_url );

			wp_redirect( $redirect );
			exit();
		}

		// $license_data->license will be either "valid" or "invalid"
		update_option( 'rcpbp_license_status', $license_data->license );
		wp_redirect( admin_url( 'admin.php?page=' . RCPBP_PLUGIN_LICENSE_PAGE ) );
		exit();

	}

	public function deactivate_license() {

		// listen for our activate button to be clicked
		if ( ! isset( $_POST['rcpbp_license_deactivate'], $_POST['rcpbp_nonce'] ) ) {
			return;
		}

		// run a quick security check
		if ( ! check_admin_referer( 'rcpbp_nonce', 'rcpbp_nonce' ) ) {
			return;
		}

		// retrieve the license from the database
		$license = trim( get_option( 'rcpbp_license_key' ) );

		// data to send in our API request
		$api_params = array(
			'edd_action' => 'deactivate_license',
			'license'    => $license,
			'item_name'  => urlencode( RCPBP_ITEM_NAME ), // the name of our product in EDD
			'url'        => home_url()
		);

		// Call the custom API.
		$response = wp_remote_post( RCPBP_STORE_URL, array(
			'timeout'   => 15,
			'sslverify' => false,
			'body'      => $api_params
		) );

		// make sure the response came back okay
		if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {

			if ( is_wp_error( $response ) ) {
				$message = $response->get_error_message();
			} else {
				$message = __( 'An error occurred, please try again.' );
			}

			$base_url = admin_url( 'admin.php?page=' . RCPBP_PLUGIN_LICENSE_PAGE );
			$redirect = add_query_arg( array(
				'sl_activation' => 'false',
				'message'       => urlencode( $message )
			), $base_url );

			wp_redirect( $redirect );
			exit();
		}

		// decode the license data
		$license_data = json_decode( wp_remote_retrieve_body( $response ) );

		// $license_data->license will be either "deactivated" or "failed"
		if ( $license_data->license == 'deactivated' ) {
			delete_option( 'rcpbp_license_status' );
			set_transient( 'rcpbp_license_check', $license_data->license, DAY_IN_SECONDS );
		}

		wp_redirect( admin_url( 'admin.php?page=' . RCPBP_PLUGIN_LICENSE_PAGE ) );
		exit();

	}

	/**
	 * This is a means of catching errors from the activation method above and displaying it to the customer
	 */
	public function license_admin_notice() {
		if ( isset( $_GET['sl_activation'] ) && ! empty( $_GET['message'] ) ) {

			switch ( $_GET['sl_activation'] ) {

				case 'false':
					$message = urldecode( $_GET['message'] );
					?>
                    <div class="error">
                        <p><?php echo $message; ?></p>
                    </div>
					<?php
					break;

				case 'true':
				default:
					// Developers can put a custom success message here for when activation is successful if they way.
					break;

			}
		}
	}

	/**
	 * Notice showing that multiple memberships are not supported.
	 */
	public function rcp_version_notice() {

		if ( ! function_exists( 'rcp_multiple_memberships_enabled' ) ) {
			return;
		}

	}

	// Callback for visibility section toggle (enable/disable)
	public function rcpbp_components_toggle_callback() {
		printf('<input type="checkbox" id="rcpbp-components-toggle" name="rcpbp_components_toggle" %s value="1" />', checked( get_option( 'rcpbp_components_toggle' ), 1, false ) );
		printf( '<label>%s</label>', __( 'Enable BuddyPress component restriction.', 'rcpbp' ) );
	}

	// Callback for visibility section toggle (enable/disable)
	public function rcpbp_bp_vis_toggle_callback() {
		printf('<input type="checkbox" id="rcpbp-bp-vis-rd-toggle" name="rcpbp_bp_vis_rd_toggle" %s value="1" />', checked( get_option( 'rcpbp_vis_rd_toggle' ), 1, false ) );
		printf( '<label>%s</label>', __( 'Restrict logged out users from accessing any BuddyPress content.', 'rcpbp' ) );
	}

	// Callback for visibility section page dropdown
	public function rcpbp_bp_vis_rd_page_callback() {
		$pages  = get_pages();
		$option = get_option( 'rcpbp_vis_rd_page' );
		wp_dropdown_pages(
			array(
				'selected' => $option,
				'id'       => 'rcpbp-bp-vis-rd-page',
				'name'     => 'rcpbp_bp_vis_rd_page'
			)
		);
		printf( '<p class="description">%s</p>', __( 'Select which page users should be redirected to.', 'rcpbp' ) );
	}

	/**
	 * Output member types toggle field
	 */
	public function rcpbp_memtype_toggle_callback() {
		echo '<input type="checkbox" id="rcpbp-memtype-toggle" name="rcpbp_memtype_toggle" value="1" ';
		checked( get_option( 'rcpbp_memtype_toggle' ), 1 );
		echo '/>';
	}

}

/**
 * Check license
 *
 * @since       1.0.0
 */
function rcpbp_check_license() {
	// Don't fire when saving settings
	if ( ! empty( $_POST['rcpbp_nonce'] ) ) {
		return;
	}

	$license = get_option( 'rcpbp_license_key' );
	$status  = get_transient( 'rcpbp_license_check' );

	if ( $status === false && $license ) {

		$api_params = array(
			'edd_action' => 'check_license',
			'license'    => trim( $license ),
			'item_name'  => urlencode( RCPBP_ITEM_NAME ),
			'url'        => home_url()
		);

		$response = wp_remote_post( RCPBP_STORE_URL, array(
			'timeout'   => 35,
			'sslverify' => false,
			'body'      => $api_params
		) );

		if ( is_wp_error( $response ) ) {
			return;
		}

		$license_data = json_decode( wp_remote_retrieve_body( $response ) );

		$status = $license_data->license;

		update_option( 'rcpbp_license_status', $status );

		set_transient( 'rcpbp_license_check', $license_data->license, DAY_IN_SECONDS );

		if ( $status !== 'valid' ) {
			delete_option( 'rcpbp_license_status' );
		}
	}

}

add_action( 'admin_init', 'rcpbp_check_license' );