const {src, dest, watch, series } = require('gulp');
let wp_pot = require('gulp-wp-pot');

/**
 * Update language reference in the main Pot file.
 *
 * @since 3.5.33
 * @author Israel Barragan <reedyseth@gmail.com>
 */
function translate() {
	return src( [
		'**/*.php',
		'!vendor/**',
		'!node_modules/**',
	] )
		.pipe( wp_pot({
			domain: 'rcp',
			package: 'Restrict Content Pro'
		}))
		.pipe( dest( 'languages/rcp.pot' ) );
}

/**
 * Move plugin source code
 *
 * @since 29-Jun-20
 * @author Israel Barragan <reedyseth@gmail.com>
 */
function plugin_code() {
	return src([
		'**/*',
		'!admin/sass',
		'!public/sass',
		'!{bin,bin/**}',
		'!{tests,tests/**}',
		'!{build,build/**}',
		'!{node_modules,node_modules/**}',
		'!vendor/{dealerdirect,dealerdirect/**}',
		'!vendor/{squizlabs,squizlabs/**}',
		'!vendor/{wp-coding-standards,wp-coding-standards/**}',
		'!vendor/{bin,bin/**}',
		'!vendor/{doctrine,doctrine/**}',
		'!vendor/{myclabs,myclabs/**}',
		'!vendor/{phpdocumentor,phpdocumentor/**}',
		'!vendor/{phpspec,phpspec/**}',
		'!vendor/{phpunit,phpunit/**}',
		'!vendor/{sebastian,sebastian/**}',
		'!vendor/{symfony,symfony/**}',
		'!vendor/{theseer,theseer/**}',
		'!vendor/{webmozart,webmozart/**}',
		'!vendor/{phar-io,phar-io/**}',
		'!vendor/{twig,twig/**}',
		'!.gitignore',
		'!package-lock.json',
		'!package.json',
		'!composer.lock',
		'!tags',
		'!phpcs.xml',
		'!phpunit.xml.dist',
		'!gulpfile.js'
	])
		.pipe(dest('./build/'));
}

let copy = series( plugin_code );
let build_plugin = series( series( plugin_code ) );
let traduce = series( translate );

exports.copy = copy;
exports.build = build_plugin;
exports.traduce = traduce;

exports.default = function() {
	watch( './core/**/*.php', traduce );
	watch( './pro/**/*.php', traduce );
};
